r'''
# 🚧 GitHub Actions CDK

**github-actions-cdk** is a TypeScript library that simplifies the creation and management of GitHub Actions workflows using Constructs. With this library, developers can define workflows in a structured and type-safe manner, making it easier to automate CI/CD pipelines on GitHub.

## Features

* **Type-Safe Workflows**: Leverage TypeScript's strong typing to define your GitHub Actions workflows and ensure correctness.
* **Modular Design**: Easily create and manage jobs, triggers, and options for your workflows.
* **Built-In Support for GitHub Events**: Configure workflows based on various GitHub events such as push, pull request, issue comments, and more.
* **Customizable Options**: Define environment variables, permissions, concurrency settings, and default job settings.

## Installation

To get started with `github-actions-cdk`, install the package using npm or yarn:

```bash
npm install github-actions-cdk
```

or

```bash
yarn add github-actions-cdk
```

## Getting Started

### Basic Usage

Here's a simple example of how to create a GitHub Actions workflow using `github-actions-cdk`:

```python
import { PermissionLevel, Project } from 'github-actions-cdk';
import { Checkout, SetupNode } from 'github-actions-cdk/actions';

const project = new Project();

const workflow = project.addWorkflow('build', {
    name: "Build",
    triggers: {
        push: { branches: ['main'] },
        workflowDispatch: {}
    },
    permissions: {
        contents: PermissionLevel.READ,
    }
});

const job = workflow.addJob('build', {
	env: {
		CI: 'true',
	},
});

job.addAction(
  new Checkout("checkout", {
    name: "Checkout Code",
    version: "v4",
  }),
);

job.addAction(
  new SetupNode("setup-node", {
    name: "Set up Node.js",
    version: "v4",
    nodeVersion: "20.x",
  }),
);

project.synth();
```

## Contributing

Contributions are welcome! Please read the [CONTRIBUTING.md](./CONTRIBUTING.md) for details on how to get involved.

## License

This project is licensed under the MIT License. See the [LICENSE](./LICENCE) file for more information.
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import constructs as _constructs_77d1e7e8


class Action(metaclass=jsii.JSIIAbstractClass, jsii_type="github-actions-cdk.Action"):
    '''(experimental) Abstract representation of a GitHub Action bound to a Job.

    Actions are reusable units in GitHub Actions workflows for performing tasks.
    Subclasses should implement the ``bind`` method for specific job interactions.

    :stability: experimental
    '''

    def __init__(
        self,
        id: builtins.str,
        *,
        version: builtins.str,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Initializes an Action instance.

        :param id: - Unique identifier for the action.
        :param version: (experimental) The version of the action, can be a specific version, tag, or commit SHA.
        :param name: (experimental) Optional name for the action, displayed in logs.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9083af845695d517fd188c807376a21723381078b0375f588720ba0e18af144)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = ActionProps(version=version, name=name)

        jsii.create(self.__class__, self, [id, props])

    @jsii.member(jsii_name="bind")
    @abc.abstractmethod
    def bind(self, job: "Job") -> "Step":
        '''(experimental) Binds the action to a specified Job within the workflow.

        :param job: - The Job to bind the Action to.

        :return: A Step that integrates the action into the job.

        :stability: experimental
        '''
        ...

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        '''(experimental) Unique identifier for the action, must be unique within a job.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="outputs")
    @abc.abstractmethod
    def outputs(self) -> typing.Mapping[builtins.str, builtins.str]:
        '''(experimental) Outputs generated by the action, structured according to T.

        :stability: experimental
        '''
        ...

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        '''(experimental) Version of the action to use in the workflow.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Optional name for display in workflow logs.

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))


class _ActionProxy(Action):
    @jsii.member(jsii_name="bind")
    def bind(self, job: "Job") -> "Step":
        '''(experimental) Binds the action to a specified Job within the workflow.

        :param job: - The Job to bind the Action to.

        :return: A Step that integrates the action into the job.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__248c74fec40098022456d69af388ef2f6b3ae1d3aebe3b790420bcff20621841)
            check_type(argname="argument job", value=job, expected_type=type_hints["job"])
        return typing.cast("Step", jsii.invoke(self, "bind", [job]))

    @builtins.property
    @jsii.member(jsii_name="outputs")
    def outputs(self) -> typing.Mapping[builtins.str, builtins.str]:
        '''(experimental) Outputs generated by the action, structured according to T.

        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "outputs"))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
typing.cast(typing.Any, Action).__jsii_proxy_class__ = lambda : _ActionProxy


@jsii.data_type(
    jsii_type="github-actions-cdk.ActionProps",
    jsii_struct_bases=[],
    name_mapping={"version": "version", "name": "name"},
)
class ActionProps:
    def __init__(
        self,
        *,
        version: builtins.str,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Properties required to configure an Action.

        :param version: (experimental) The version of the action, can be a specific version, tag, or commit SHA.
        :param name: (experimental) Optional name for the action, displayed in logs.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c67d92ddddb47d887e29da7bf6b0e42ad1021d78b44eb09fe02d19b70124b79)
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "version": version,
        }
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def version(self) -> builtins.str:
        '''(experimental) The version of the action, can be a specific version, tag, or commit SHA.

        :stability: experimental

        Example::

            version: "v2"
        '''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Optional name for the action, displayed in logs.

        :stability: experimental

        Example::

            "Checkout Repository"
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ActionProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.CheckRunOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class CheckRunOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for check run events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5072f3495f4b3ba39176b029f0940e9c79221c2d0e31e596908947c243e493d1)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CheckRunOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.CheckSuiteOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class CheckSuiteOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for check suite events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e104de4e65a228ba7996b869572411dc7ad5e1a2a7d6121de1f6ccd55f0e0e0)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CheckSuiteOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Component(
    _constructs_77d1e7e8.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="github-actions-cdk.Component",
):
    '''(experimental) Represents a GitHub Actions CDK Component, extending the base ``Construct`` class.

    The ``Component`` class serves as a foundational construct within GitHub Actions workflows
    and adds unique identifiers, type metadata, and markers for internal component
    identification.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.IConstruct,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Initializes a new ``Component`` instance.

        :param scope: - The scope in which this component is defined.
        :param id: - The unique identifier for this component. If not provided, an auto-generated ID is used based on the component name and scope.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cead5b79c90c5d033e0e67c6a4b6ab32d75b9b25a356a33e670e380460cbd641)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        jsii.create(self.__class__, self, [scope, id])

    @jsii.member(jsii_name="isComponent")
    @builtins.classmethod
    def is_component(cls, x: typing.Any) -> builtins.bool:
        '''(experimental) Checks if an object is an instance of ``Component``.

        This static method uses a unique symbol to verify if the input object has
        been marked as a ``Component``.

        :param x: - The object to check.

        :return: ``true`` if ``x`` is a ``Component``; otherwise, ``false``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fdef1626108471936d90bdb773b97c0ad75e293b12de823502fcf8c725662c2)
            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
        return typing.cast(builtins.bool, jsii.sinvoke(cls, "isComponent", [x]))


@jsii.data_type(
    jsii_type="github-actions-cdk.ConcurrencyOptions",
    jsii_struct_bases=[],
    name_mapping={"group": "group", "cancel_in_progress": "cancelInProgress"},
)
class ConcurrencyOptions:
    def __init__(
        self,
        *,
        group: builtins.str,
        cancel_in_progress: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''(experimental) Options for job concurrency control in GitHub Actions workflows.

        GitHub Actions concurrency allows you to limit and control the number of jobs or workflows
        that can run simultaneously within a specified concurrency group. When concurrency is enabled,
        GitHub will cancel or queue jobs to avoid duplicate or conflicting runs, ensuring that only
        one job from the group runs at a time.

        For further details, see the GitHub Actions concurrency documentation:

        :param group: (experimental) The concurrency group to use for the job. The ``group`` property defines a unique identifier for the concurrency group. Only one job or workflow within the same concurrency group will run at a time. This group can be a simple string or a dynamically generated value using expressions.
        :param cancel_in_progress: (experimental) Specifies whether to cancel any currently running jobs or workflows in the same concurrency group. If set to ``true``, any currently running jobs or workflows within the same concurrency group will be canceled in favor of the latest job. If set to ``false`` or not provided, jobs will be queued to wait until any currently running jobs in the group complete. Default: false

        :see: https://docs.github.com/en/actions/using-jobs/using-concurrency
        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b13408e5c019460595cf165919cb1c57a2410148d6fb00d9d9defcb7d65e776)
            check_type(argname="argument group", value=group, expected_type=type_hints["group"])
            check_type(argname="argument cancel_in_progress", value=cancel_in_progress, expected_type=type_hints["cancel_in_progress"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "group": group,
        }
        if cancel_in_progress is not None:
            self._values["cancel_in_progress"] = cancel_in_progress

    @builtins.property
    def group(self) -> builtins.str:
        '''(experimental) The concurrency group to use for the job.

        The ``group`` property defines a unique identifier for the concurrency group. Only one job
        or workflow within the same concurrency group will run at a time. This group can be a
        simple string or a dynamically generated value using expressions.

        :stability: experimental

        Example::

            // Use an expression to create a dynamic group for each branch
            group: "${{ github.ref }}"
        '''
        result = self._values.get("group")
        assert result is not None, "Required property 'group' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cancel_in_progress(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Specifies whether to cancel any currently running jobs or workflows in the same concurrency group.

        If set to ``true``, any currently running jobs or workflows within the same concurrency group
        will be canceled in favor of the latest job. If set to ``false`` or not provided, jobs will
        be queued to wait until any currently running jobs in the group complete.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("cancel_in_progress")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConcurrencyOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Cron(metaclass=jsii.JSIIMeta, jsii_type="github-actions-cdk.Cron"):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[builtins.str] = None,
        minute: typing.Optional[builtins.str] = None,
        month: typing.Optional[builtins.str] = None,
        week_day: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Constructs a new Cron instance using the specified options.

        Generates a cron expression string from the input fields and validates it.

        :param day: (experimental) Specifies the day(s) of the month the cron job should run. Use ``*`` for every day, or specify a day (1-31). Supports ``L`` for the last day of the month and ``W`` for weekdays. Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every day of the month
        :param hour: (experimental) Specifies the hour(s) the cron job should run. Use ``*`` for every hour or specify a specific hour (0-23). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every hour
        :param minute: (experimental) Specifies the minute(s) the cron job should run. Use ``*`` for every minute or specify a specific minute (0-59). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every minute
        :param month: (experimental) Specifies the month(s) the cron job should run. Use ``*`` for every month or specify a month (1-12 or JAN-DEC). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every month
        :param week_day: (experimental) Specifies the day(s) of the week the cron job should run. Use ``*`` for every day of the week, or specify a specific day (0-6 or SUN-SAT). Supports ``L`` for the last instance and ``#`` for specifying nth occurrence of the day in the month. Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Any day of the week

        :stability: experimental
        :throws: Will throw an error if the generated cron expression is invalid.
        '''
        props = CronOptions(
            day=day, hour=hour, minute=minute, month=month, week_day=week_day
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="fromExpression")
    @builtins.classmethod
    def from_expression(cls, expression: builtins.str) -> "Cron":
        '''(experimental) Creates a Cron instance from a single cron expression string.

        :param expression: - The cron expression string.

        :return: A new Cron instance based on the provided expression.

        :stability: experimental
        :throws: Will throw an error if the expression is invalid.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__421e7476c56b104ee34b40b641f796adb4f6ed1124a2b669faba030276256f6c)
            check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
        return typing.cast("Cron", jsii.sinvoke(cls, "fromExpression", [expression]))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> builtins.str:
        '''(experimental) Converts the Cron instance to a JSON representation (string format).

        :return: The cron expression string.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "toJSON", []))

    @jsii.member(jsii_name="toString")
    def to_string(self) -> builtins.str:
        '''(experimental) Converts the Cron instance to a cron expression string.

        :return: The cron expression string in "minute hour day month weekDay" format.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "toString", []))

    @builtins.property
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property
    @jsii.member(jsii_name="expression")
    def expression(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "expression"))

    @builtins.property
    @jsii.member(jsii_name="hour")
    def hour(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "hour"))

    @builtins.property
    @jsii.member(jsii_name="minute")
    def minute(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "minute"))

    @builtins.property
    @jsii.member(jsii_name="month")
    def month(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "month"))

    @builtins.property
    @jsii.member(jsii_name="weekDay")
    def week_day(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "weekDay"))


@jsii.data_type(
    jsii_type="github-actions-cdk.CronOptions",
    jsii_struct_bases=[],
    name_mapping={
        "day": "day",
        "hour": "hour",
        "minute": "minute",
        "month": "month",
        "week_day": "weekDay",
    },
)
class CronOptions:
    def __init__(
        self,
        *,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[builtins.str] = None,
        minute: typing.Optional[builtins.str] = None,
        month: typing.Optional[builtins.str] = None,
        week_day: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param day: (experimental) Specifies the day(s) of the month the cron job should run. Use ``*`` for every day, or specify a day (1-31). Supports ``L`` for the last day of the month and ``W`` for weekdays. Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every day of the month
        :param hour: (experimental) Specifies the hour(s) the cron job should run. Use ``*`` for every hour or specify a specific hour (0-23). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every hour
        :param minute: (experimental) Specifies the minute(s) the cron job should run. Use ``*`` for every minute or specify a specific minute (0-59). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every minute
        :param month: (experimental) Specifies the month(s) the cron job should run. Use ``*`` for every month or specify a month (1-12 or JAN-DEC). Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Every month
        :param week_day: (experimental) Specifies the day(s) of the week the cron job should run. Use ``*`` for every day of the week, or specify a specific day (0-6 or SUN-SAT). Supports ``L`` for the last instance and ``#`` for specifying nth occurrence of the day in the month. Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``. Default: "*" - Any day of the week

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f87d77789ba0ef97f504cc1ff5b1ad08e4c6aaf974d775c90a3fa4d819bc2d9)
            check_type(argname="argument day", value=day, expected_type=type_hints["day"])
            check_type(argname="argument hour", value=hour, expected_type=type_hints["hour"])
            check_type(argname="argument minute", value=minute, expected_type=type_hints["minute"])
            check_type(argname="argument month", value=month, expected_type=type_hints["month"])
            check_type(argname="argument week_day", value=week_day, expected_type=type_hints["week_day"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour
        if minute is not None:
            self._values["minute"] = minute
        if month is not None:
            self._values["month"] = month
        if week_day is not None:
            self._values["week_day"] = week_day

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the day(s) of the month the cron job should run.

        Use ``*`` for every day, or specify a day (1-31).
        Supports ``L`` for the last day of the month and ``W`` for weekdays.
        Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``.

        :default: "*" - Every day of the month

        :stability: experimental
        '''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the hour(s) the cron job should run.

        Use ``*`` for every hour or specify a specific hour (0-23).
        Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``.

        :default: "*" - Every hour

        :stability: experimental
        '''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def minute(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the minute(s) the cron job should run.

        Use ``*`` for every minute or specify a specific minute (0-59).
        Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``.

        :default: "*" - Every minute

        :stability: experimental
        '''
        result = self._values.get("minute")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def month(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the month(s) the cron job should run.

        Use ``*`` for every month or specify a month (1-12 or JAN-DEC).
        Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``.

        :default: "*" - Every month

        :stability: experimental
        '''
        result = self._values.get("month")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def week_day(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the day(s) of the week the cron job should run.

        Use ``*`` for every day of the week, or specify a specific day (0-6 or SUN-SAT).
        Supports ``L`` for the last instance and ``#`` for specifying nth occurrence of the day in the month.
        Multiple values can be separated by commas, ranges with ``-``, and intervals with ``/``.

        :default: "*" - Any day of the week

        :stability: experimental
        '''
        result = self._values.get("week_day")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CronOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.CronScheduleOptions",
    jsii_struct_bases=[],
    name_mapping={"cron": "cron"},
)
class CronScheduleOptions:
    def __init__(self, *, cron: Cron) -> None:
        '''(experimental) Options for configuring CRON schedule.

        :param cron: (experimental) CRON expression to define workflow schedule.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__199600a8fe0c62df3cbff7bfcacbbf2f8e629df37768f92e7958220548d6dd60)
            check_type(argname="argument cron", value=cron, expected_type=type_hints["cron"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "cron": cron,
        }

    @builtins.property
    def cron(self) -> Cron:
        '''(experimental) CRON expression to define workflow schedule.

        :see: https://pubs.opengroup.org/onlinepubs/9699919799/utilities/crontab.html#tag_20_25_07
        :stability: experimental
        '''
        result = self._values.get("cron")
        assert result is not None, "Required property 'cron' is missing"
        return typing.cast(Cron, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CronScheduleOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.Defaults",
    jsii_struct_bases=[],
    name_mapping={"run": "run"},
)
class Defaults:
    def __init__(
        self,
        *,
        run: typing.Optional[typing.Union["RunSettings", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''(experimental) Default settings applied to all steps within a job.

        ``Defaults`` provides a consistent configuration that applies to every step in the job,
        ensuring uniformity in settings like ``shell`` and ``workingDirectory``. These settings
        can be overridden in individual steps as needed.

        :param run: (experimental) Default run settings to apply across all steps in the job. Use ``run`` to define the shell and working directory settings that should be applied to each step, unless overridden at the step level.

        :stability: experimental
        '''
        if isinstance(run, dict):
            run = RunSettings(**run)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37fef6d91b1101241267e5d35cbcd7e3ed2eb1139f4522bfcd355fc98907624f)
            check_type(argname="argument run", value=run, expected_type=type_hints["run"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if run is not None:
            self._values["run"] = run

    @builtins.property
    def run(self) -> typing.Optional["RunSettings"]:
        '''(experimental) Default run settings to apply across all steps in the job.

        Use ``run`` to define the shell and working directory settings that should
        be applied to each step, unless overridden at the step level.

        :stability: experimental
        '''
        result = self._values.get("run")
        return typing.cast(typing.Optional["RunSettings"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Defaults(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.IssueCommentOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class IssueCommentOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for issue comment events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9245f610dfdf28f8846ab53cd23fb911806e86522c4cea0c3e62e5529532c5bc)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IssueCommentOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.IssuesOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class IssuesOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for issue events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf87540107a62d8d64ed58e95f8b01db8159513fdd767fdd8c3f30aa87899b9e)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IssuesOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Job(Component, metaclass=jsii.JSIIMeta, jsii_type="github-actions-cdk.Job"):
    '''(experimental) Represents a GitHub Actions job, including configuration and steps.

    A job consists of multiple steps that execute within a specified runner environment,
    with access to defined environment variables, default settings, and permissions. The
    ``Job`` class allows for the addition of steps and actions, and manages job dependencies
    and environment configurations.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.IConstruct,
        id: builtins.str,
        *,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        environment: typing.Any = None,
        name: typing.Optional[builtins.str] = None,
        needs: typing.Optional[typing.Sequence[builtins.str]] = None,
        outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        permissions: typing.Optional[typing.Union[typing.Union["PermissionsEvent", typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
        runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        strategy: typing.Optional[typing.Union["Strategy", typing.Dict[builtins.str, typing.Any]]] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''(experimental) Creates a new Job instance.

        :param scope: - The scope in which to define this construct.
        :param id: - The unique identifier for the job within the workflow.
        :param defaults: (experimental) Default settings to apply to all steps in the job. These settings provide default values for ``shell``, ``workingDirectory``, and other options for each step in the job, allowing for consistent configuration across steps. Job-level defaults can override workflow-level defaults, but can be overridden by individual step settings.
        :param env: (experimental) Environment variables available to all steps in the job. A key-value map of environment variables that are accessible by all steps within this job. Individual steps or the entire workflow can also set environment variables to further customize the environment.
        :param environment: (experimental) The environment this job targets. Specifies the GitHub environment referenced by this job. The job will be subject to any environment protection rules configured in the repository, such as approvals or restrictions.
        :param name: (experimental) The display name of the job in GitHub Actions. This name will appear in the Actions interface to represent this job.
        :param needs: (experimental) Specifies any jobs that must complete before this job runs. This property establishes dependencies between jobs, ensuring that specified jobs complete successfully before this job is initiated. It can be a string or an array of job IDs.
        :param outputs: (experimental) Defines outputs for the job that can be accessed by downstream jobs. A map of outputs produced by this job, which are accessible to other jobs that depend on it via the ``needs`` keyword.
        :param permissions: (experimental) Defines the permissions for this job. Use this to control the access levels and permissions available to the job, restricting or granting permissions for specific GitHub actions and resources.
        :param required_checks: (experimental) A set of required checks that must pass before the job can run. Useful for ensuring that certain status checks are completed before executing this job, improving the reliability of the workflow.
        :param runner_labels: (experimental) Specifies the job's runner labels. This allows you to filter runners by labels, which is particularly useful for self-hosted runners. You can provide a single label or an array of labels.
        :param runs_on: (experimental) The type of runner on which to execute the job. Defines the runner environment for the job, which can be either a GitHub-hosted or self-hosted runner. GitHub-hosted runners include options such as ``"ubuntu-latest"``, ``"windows-latest"``, and ``"macos-latest"``.
        :param strategy: (experimental) The strategy for running this job. Allows you to specify a matrix strategy to run the job multiple times with different configurations, like different Node.js versions or OS types.
        :param timeout_minutes: (experimental) The timeout in minutes for the job to complete. This defines how long GitHub Actions should wait for the job to finish before it is automatically canceled. This helps in managing long-running jobs. Default: 60

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba74ac8c28c96ce71749c13835adfaf0239f2f521dd066f17e0e73c75ff7d315)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = JobProps(
            defaults=defaults,
            env=env,
            environment=environment,
            name=name,
            needs=needs,
            outputs=outputs,
            permissions=permissions,
            required_checks=required_checks,
            runner_labels=runner_labels,
            runs_on=runs_on,
            strategy=strategy,
            timeout_minutes=timeout_minutes,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addAction")
    def add_action(self, action: Action) -> None:
        '''(experimental) Binds an action to this job.

        Associates the specified action with this job, applying its configuration
        and behavior to the job's steps.

        :param action: - The action to bind to the job.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14666f0e16559875db8b555895bfc36563ba36305480f7bd9e1f3cf88ceeca66)
            check_type(argname="argument action", value=action, expected_type=type_hints["action"])
        return typing.cast(None, jsii.invoke(self, "addAction", [action]))

    @jsii.member(jsii_name="addOutput")
    def add_output(self, name: builtins.str, value: builtins.str) -> None:
        '''(experimental) Adds an output to the job.

        Outputs can be used by downstream jobs that depend on this job.

        :param name: - The name of the output.
        :param value: - The value of the output.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c84ddb7613f0dc156744978622a36eaccf42eb24f73fb68aadd45210e8a453a)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast(None, jsii.invoke(self, "addOutput", [name, value]))

    @jsii.member(jsii_name="addStep")
    def add_step(
        self,
        id: builtins.str,
        *,
        condition: typing.Optional[builtins.str] = None,
        continue_on_error: typing.Optional[builtins.bool] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        run: typing.Optional[typing.Sequence[builtins.str]] = None,
        shell: typing.Optional[builtins.str] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
        uses: typing.Optional[builtins.str] = None,
        working_directory: typing.Optional[builtins.str] = None,
    ) -> "Step":
        '''(experimental) Adds a step to the job.

        Each step defines a specific command or set of commands to be executed in sequence within the job.

        :param id: - The id of the step.
        :param condition: (experimental) Conditional expression to determine if the step should run. (corresponds to ``if`` in GitHub Actions). This can include GitHub Actions contexts and expressions, allowing conditions like ``${{ success() }}`` or ``${{ github.event_name == 'push' }}``.
        :param continue_on_error: (experimental) Controls whether the job should continue if this step fails. Set to ``true`` to allow the job to proceed even if this step encounters an error. Default: false
        :param env: (experimental) Environment variables available to this step. Step-specific environment variables are accessible within the shell or action, overriding any workflow or job-level environment settings.
        :param name: (experimental) A descriptive name for the step, displayed in the GitHub Actions UI.
        :param parameters: (experimental) Input parameters for the action specified in ``uses``. (corresponds to ``with`` in GitHub Actions). This is a key-value map of input parameters that the action can access as environment variables, each prefixed with ``INPUT_``.
        :param run: (experimental) A shell command or script to run in this step. Runs specified command-line programs or scripts in the step's shell. If ``name`` is not specified, this command's text will display as the step name.
        :param shell: (experimental) A shell specification to define the shell environment for this step. Allows specifying a shell other than the default, such as ``bash``, ``powershell``, etc. Default: "bash"
        :param timeout_minutes: (experimental) Maximum execution time for the step, in minutes. After this time, the step is terminated to prevent indefinite execution.
        :param uses: (experimental) Specifies an action to run in this step. Defines a reusable action from the same repository, a public repository, or a Docker container. Actions provide predefined functionality to avoid custom scripting for common tasks.
        :param working_directory: (experimental) Specifies the working directory for the step. Sets the directory in which the step's command or action runs. If not specified, it defaults to the job's working directory.

        :return: The newly created step instance.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77084fa240cf0938b5ba7ecabdd97e763b728b544776f87ea0b277d4ce0b8c4c)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = StepProps(
            condition=condition,
            continue_on_error=continue_on_error,
            env=env,
            name=name,
            parameters=parameters,
            run=run,
            shell=shell,
            timeout_minutes=timeout_minutes,
            uses=uses,
            working_directory=working_directory,
        )

        return typing.cast("Step", jsii.invoke(self, "addStep", [id, props]))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        '''(experimental) Retrieves the unique identifier for this job.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="runsOn")
    def runs_on(self) -> typing.Union[builtins.str, typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[builtins.str, typing.List[builtins.str]], jsii.get(self, "runsOn"))

    @builtins.property
    @jsii.member(jsii_name="defaults")
    def defaults(self) -> typing.Optional[Defaults]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[Defaults], jsii.get(self, "defaults"))

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "env"))

    @builtins.property
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.Any:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.get(self, "environment"))

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @builtins.property
    @jsii.member(jsii_name="needs")
    def needs(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "needs"))

    @builtins.property
    @jsii.member(jsii_name="outputs")
    def outputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''(experimental) Retrieves the outputs defined for this job.

        :return: A map of output names to their values.

        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "outputs"))

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union["PermissionsEvent", builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union["PermissionsEvent", builtins.str]], jsii.get(self, "permissions"))

    @builtins.property
    @jsii.member(jsii_name="requiredChecks")
    def required_checks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "requiredChecks"))

    @builtins.property
    @jsii.member(jsii_name="runnerLabels")
    def runner_labels(
        self,
    ) -> typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]], jsii.get(self, "runnerLabels"))

    @builtins.property
    @jsii.member(jsii_name="strategy")
    def strategy(self) -> typing.Optional["Strategy"]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional["Strategy"], jsii.get(self, "strategy"))

    @builtins.property
    @jsii.member(jsii_name="timeoutMinutes")
    def timeout_minutes(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "timeoutMinutes"))


@jsii.data_type(
    jsii_type="github-actions-cdk.JobProps",
    jsii_struct_bases=[],
    name_mapping={
        "defaults": "defaults",
        "env": "env",
        "environment": "environment",
        "name": "name",
        "needs": "needs",
        "outputs": "outputs",
        "permissions": "permissions",
        "required_checks": "requiredChecks",
        "runner_labels": "runnerLabels",
        "runs_on": "runsOn",
        "strategy": "strategy",
        "timeout_minutes": "timeoutMinutes",
    },
)
class JobProps:
    def __init__(
        self,
        *,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        environment: typing.Any = None,
        name: typing.Optional[builtins.str] = None,
        needs: typing.Optional[typing.Sequence[builtins.str]] = None,
        outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        permissions: typing.Optional[typing.Union[typing.Union["PermissionsEvent", typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
        runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        strategy: typing.Optional[typing.Union["Strategy", typing.Dict[builtins.str, typing.Any]]] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''(experimental) Configuration properties for a GitHub Actions job.

        :param defaults: (experimental) Default settings to apply to all steps in the job. These settings provide default values for ``shell``, ``workingDirectory``, and other options for each step in the job, allowing for consistent configuration across steps. Job-level defaults can override workflow-level defaults, but can be overridden by individual step settings.
        :param env: (experimental) Environment variables available to all steps in the job. A key-value map of environment variables that are accessible by all steps within this job. Individual steps or the entire workflow can also set environment variables to further customize the environment.
        :param environment: (experimental) The environment this job targets. Specifies the GitHub environment referenced by this job. The job will be subject to any environment protection rules configured in the repository, such as approvals or restrictions.
        :param name: (experimental) The display name of the job in GitHub Actions. This name will appear in the Actions interface to represent this job.
        :param needs: (experimental) Specifies any jobs that must complete before this job runs. This property establishes dependencies between jobs, ensuring that specified jobs complete successfully before this job is initiated. It can be a string or an array of job IDs.
        :param outputs: (experimental) Defines outputs for the job that can be accessed by downstream jobs. A map of outputs produced by this job, which are accessible to other jobs that depend on it via the ``needs`` keyword.
        :param permissions: (experimental) Defines the permissions for this job. Use this to control the access levels and permissions available to the job, restricting or granting permissions for specific GitHub actions and resources.
        :param required_checks: (experimental) A set of required checks that must pass before the job can run. Useful for ensuring that certain status checks are completed before executing this job, improving the reliability of the workflow.
        :param runner_labels: (experimental) Specifies the job's runner labels. This allows you to filter runners by labels, which is particularly useful for self-hosted runners. You can provide a single label or an array of labels.
        :param runs_on: (experimental) The type of runner on which to execute the job. Defines the runner environment for the job, which can be either a GitHub-hosted or self-hosted runner. GitHub-hosted runners include options such as ``"ubuntu-latest"``, ``"windows-latest"``, and ``"macos-latest"``.
        :param strategy: (experimental) The strategy for running this job. Allows you to specify a matrix strategy to run the job multiple times with different configurations, like different Node.js versions or OS types.
        :param timeout_minutes: (experimental) The timeout in minutes for the job to complete. This defines how long GitHub Actions should wait for the job to finish before it is automatically canceled. This helps in managing long-running jobs. Default: 60

        :stability: experimental
        '''
        if isinstance(defaults, dict):
            defaults = Defaults(**defaults)
        if isinstance(strategy, dict):
            strategy = Strategy(**strategy)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20769971cc29ac6695fc59fa70f7ce92e7e4f43121f480d0ffcda1a97016201b)
            check_type(argname="argument defaults", value=defaults, expected_type=type_hints["defaults"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument needs", value=needs, expected_type=type_hints["needs"])
            check_type(argname="argument outputs", value=outputs, expected_type=type_hints["outputs"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument required_checks", value=required_checks, expected_type=type_hints["required_checks"])
            check_type(argname="argument runner_labels", value=runner_labels, expected_type=type_hints["runner_labels"])
            check_type(argname="argument runs_on", value=runs_on, expected_type=type_hints["runs_on"])
            check_type(argname="argument strategy", value=strategy, expected_type=type_hints["strategy"])
            check_type(argname="argument timeout_minutes", value=timeout_minutes, expected_type=type_hints["timeout_minutes"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if defaults is not None:
            self._values["defaults"] = defaults
        if env is not None:
            self._values["env"] = env
        if environment is not None:
            self._values["environment"] = environment
        if name is not None:
            self._values["name"] = name
        if needs is not None:
            self._values["needs"] = needs
        if outputs is not None:
            self._values["outputs"] = outputs
        if permissions is not None:
            self._values["permissions"] = permissions
        if required_checks is not None:
            self._values["required_checks"] = required_checks
        if runner_labels is not None:
            self._values["runner_labels"] = runner_labels
        if runs_on is not None:
            self._values["runs_on"] = runs_on
        if strategy is not None:
            self._values["strategy"] = strategy
        if timeout_minutes is not None:
            self._values["timeout_minutes"] = timeout_minutes

    @builtins.property
    def defaults(self) -> typing.Optional[Defaults]:
        '''(experimental) Default settings to apply to all steps in the job.

        These settings provide default values for ``shell``, ``workingDirectory``, and other
        options for each step in the job, allowing for consistent configuration across steps.
        Job-level defaults can override workflow-level defaults, but can be overridden by
        individual step settings.

        :stability: experimental
        '''
        result = self._values.get("defaults")
        return typing.cast(typing.Optional[Defaults], result)

    @builtins.property
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''(experimental) Environment variables available to all steps in the job.

        A key-value map of environment variables that are accessible by all steps
        within this job. Individual steps or the entire workflow can also set environment
        variables to further customize the environment.

        :stability: experimental

        Example::

            env: { NODE_ENV: "production" }
        '''
        result = self._values.get("env")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def environment(self) -> typing.Any:
        '''(experimental) The environment this job targets.

        Specifies the GitHub environment referenced by this job. The job will be subject
        to any environment protection rules configured in the repository, such as approvals
        or restrictions.

        :see: https://docs.github.com/en/actions/reference/environments
        :stability: experimental
        '''
        result = self._values.get("environment")
        return typing.cast(typing.Any, result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''(experimental) The display name of the job in GitHub Actions.

        This name will appear in the Actions interface to represent this job.

        :stability: experimental
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def needs(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Specifies any jobs that must complete before this job runs.

        This property establishes dependencies between jobs, ensuring that
        specified jobs complete successfully before this job is initiated. It can
        be a string or an array of job IDs.

        :stability: experimental

        Example::

            needs: ["build", "test"]
        '''
        result = self._values.get("needs")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def outputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''(experimental) Defines outputs for the job that can be accessed by downstream jobs.

        A map of outputs produced by this job, which are accessible to other jobs
        that depend on it via the ``needs`` keyword.

        :stability: experimental

        Example::

            outputs: { artifact_path: "/path/to/artifact" }
        '''
        result = self._values.get("outputs")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union["PermissionsEvent", builtins.str]]:
        '''(experimental) Defines the permissions for this job.

        Use this to control the access levels and permissions available to the job,
        restricting or granting permissions for specific GitHub actions and resources.

        :stability: experimental
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union["PermissionsEvent", builtins.str]], result)

    @builtins.property
    def required_checks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) A set of required checks that must pass before the job can run.

        Useful for ensuring that certain status checks are completed before
        executing this job, improving the reliability of the workflow.

        :stability: experimental

        Example::

            requiredChecks: ["ci/check1", "ci/check2"]
        '''
        result = self._values.get("required_checks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def runner_labels(
        self,
    ) -> typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]]:
        '''(experimental) Specifies the job's runner labels.

        This allows you to filter runners by labels, which is particularly useful for
        self-hosted runners. You can provide a single label or an array of labels.

        :stability: experimental

        Example::

            runnerLabels: ["linux", "x64"]
        '''
        result = self._values.get("runner_labels")
        return typing.cast(typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]], result)

    @builtins.property
    def runs_on(
        self,
    ) -> typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]]:
        '''(experimental) The type of runner on which to execute the job.

        Defines the runner environment for the job, which can be either a GitHub-hosted
        or self-hosted runner. GitHub-hosted runners include options such as ``"ubuntu-latest"``,
        ``"windows-latest"``, and ``"macos-latest"``.

        :stability: experimental

        Example::

            runsOn: ["self-hosted", "linux", "x64"]
        '''
        result = self._values.get("runs_on")
        return typing.cast(typing.Optional[typing.Union[builtins.str, typing.List[builtins.str]]], result)

    @builtins.property
    def strategy(self) -> typing.Optional["Strategy"]:
        '''(experimental) The strategy for running this job.

        Allows you to specify a matrix strategy to run the job multiple times with different
        configurations, like different Node.js versions or OS types.

        :stability: experimental

        Example::

            strategy: { matrix: { node: [10, 12, 14] } }
        '''
        result = self._values.get("strategy")
        return typing.cast(typing.Optional["Strategy"], result)

    @builtins.property
    def timeout_minutes(self) -> typing.Optional[jsii.Number]:
        '''(experimental) The timeout in minutes for the job to complete.

        This defines how long GitHub Actions should wait for the job to finish
        before it is automatically canceled. This helps in managing long-running jobs.

        :default: 60

        :stability: experimental

        Example::

            timeoutMinutes: 30
        '''
        result = self._values.get("timeout_minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "JobProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.LabelOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class LabelOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for label events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb9e02a1d086f2f6835ff0ea1688329d1c317ce50ab856b1f80f5638e1cece8f)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LabelOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.Matrix",
    jsii_struct_bases=[],
    name_mapping={"domain": "domain", "exclude": "exclude", "include": "include"},
)
class Matrix:
    def __init__(
        self,
        *,
        domain: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
        exclude: typing.Optional[typing.Sequence[typing.Mapping[builtins.str, builtins.str]]] = None,
        include: typing.Optional[typing.Sequence[typing.Mapping[builtins.str, builtins.str]]] = None,
    ) -> None:
        '''
        :param domain: (experimental) Each option you define in the matrix has a key and value. The keys you define become properties in the matrix context and you can reference the property in other areas of your workflow file. For example, if you define the key os that contains an array of operating systems, you can use the matrix.os property as the value of the runs-on keyword to create a job for each operating system.
        :param exclude: (experimental) You can remove a specific configurations defined in the build matrix using the exclude option. Using exclude removes a job defined by the build matrix.
        :param include: (experimental) You can add additional configuration options to a build matrix job that already exists. For example, if you want to use a specific version of npm when the job that uses windows-latest and version 8 of node runs, you can use include to specify that additional option.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03098613492927ce72af982b6409517ead55bde8380b16f202b5570d740d05fc)
            check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
            check_type(argname="argument include", value=include, expected_type=type_hints["include"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if domain is not None:
            self._values["domain"] = domain
        if exclude is not None:
            self._values["exclude"] = exclude
        if include is not None:
            self._values["include"] = include

    @builtins.property
    def domain(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.List[builtins.str]]]:
        '''(experimental) Each option you define in the matrix has a key and value.

        The keys you
        define become properties in the matrix context and you can reference the
        property in other areas of your workflow file. For example, if you define
        the key os that contains an array of operating systems, you can use the
        matrix.os property as the value of the runs-on keyword to create a job
        for each operating system.

        :stability: experimental
        '''
        result = self._values.get("domain")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.List[builtins.str]]], result)

    @builtins.property
    def exclude(
        self,
    ) -> typing.Optional[typing.List[typing.Mapping[builtins.str, builtins.str]]]:
        '''(experimental) You can remove a specific configurations defined in the build matrix using the exclude option.

        Using exclude removes a job defined by the
        build matrix.

        :stability: experimental
        '''
        result = self._values.get("exclude")
        return typing.cast(typing.Optional[typing.List[typing.Mapping[builtins.str, builtins.str]]], result)

    @builtins.property
    def include(
        self,
    ) -> typing.Optional[typing.List[typing.Mapping[builtins.str, builtins.str]]]:
        '''(experimental) You can add additional configuration options to a build matrix job that already exists.

        For example, if you want to use a specific version of npm
        when the job that uses windows-latest and version 8 of node runs, you can
        use include to specify that additional option.

        :stability: experimental
        '''
        result = self._values.get("include")
        return typing.cast(typing.Optional[typing.List[typing.Mapping[builtins.str, builtins.str]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Matrix(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.MilestoneOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class MilestoneOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for milestone events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de2c4c22ac0039acb049ce3c2e609e65738cb30ba50ee75b76ee87ddb332ad6f)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MilestoneOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="github-actions-cdk.PermissionLevel")
class PermissionLevel(enum.Enum):
    '''(experimental) Access levels for specific workflow permission scopes.

    ``PermissionLevel`` defines the different levels of access available for
    each permission scope in a workflow. These levels determine the
    degree of interaction that GitHub Actions workflows have with repository
    resources.

    :stability: experimental
    '''

    READ = "READ"
    '''(experimental) Grants read-only access to the specified scope.

    :stability: experimental
    '''
    WRITE = "WRITE"
    '''(experimental) Grants both read and write access to the specified scope.

    :stability: experimental
    '''
    NONE = "NONE"
    '''(experimental) Explicitly denies all access to the specified scope.

    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="github-actions-cdk.PermissionsEvent",
    jsii_struct_bases=[],
    name_mapping={
        "actions": "actions",
        "checks": "checks",
        "contents": "contents",
        "deployments": "deployments",
        "discussions": "discussions",
        "id_token": "idToken",
        "issues": "issues",
        "packages": "packages",
        "pull_requests": "pullRequests",
        "repository_projects": "repositoryProjects",
        "security_events": "securityEvents",
        "statuses": "statuses",
    },
)
class PermissionsEvent:
    def __init__(
        self,
        *,
        actions: typing.Optional[PermissionLevel] = None,
        checks: typing.Optional[PermissionLevel] = None,
        contents: typing.Optional[PermissionLevel] = None,
        deployments: typing.Optional[PermissionLevel] = None,
        discussions: typing.Optional[PermissionLevel] = None,
        id_token: typing.Optional[PermissionLevel] = None,
        issues: typing.Optional[PermissionLevel] = None,
        packages: typing.Optional[PermissionLevel] = None,
        pull_requests: typing.Optional[PermissionLevel] = None,
        repository_projects: typing.Optional[PermissionLevel] = None,
        security_events: typing.Optional[PermissionLevel] = None,
        statuses: typing.Optional[PermissionLevel] = None,
    ) -> None:
        '''(experimental) Specifies detailed permission levels for individual GitHub resources in a workflow.

        Each property in ``PermissionsEvent`` represents a specific scope for which
        access can be configured. When any scope is specified, all unspecified scopes
        are set to ``PermissionLevel.NONE``, overriding the default GitHub behavior
        of automatically setting unspecified permissions to ``read`` or ``write``.

        :param actions: (experimental) Permissions for GitHub Actions, affecting access to workflows.
        :param checks: (experimental) Permissions for check runs, enabling read or write access to check details.
        :param contents: (experimental) Permissions for repository contents, controlling file and directory access.
        :param deployments: (experimental) Permissions for deployments, affecting environment deployments in the repository.
        :param discussions: (experimental) Permissions for discussions, enabling interaction with GitHub Discussions.
        :param id_token: (experimental) Permissions for the GitHub OIDC (OpenID Connect) token, allowing secure identity verification.
        :param issues: (experimental) Permissions for managing and interacting with issues in the repository.
        :param packages: (experimental) Permissions for packages in the GitHub Packages registry.
        :param pull_requests: (experimental) Permissions for interacting with pull requests in the repository.
        :param repository_projects: (experimental) Permissions for repository projects, affecting project boards and related assets.
        :param security_events: (experimental) Permissions for security events, such as vulnerability alerts.
        :param statuses: (experimental) Permissions for statuses, affecting commit statuses in the repository.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__250bfcabc87a33880947a3c29504b6eba32fdb6d7ba0d62131a0d5f9b95f3f5a)
            check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            check_type(argname="argument checks", value=checks, expected_type=type_hints["checks"])
            check_type(argname="argument contents", value=contents, expected_type=type_hints["contents"])
            check_type(argname="argument deployments", value=deployments, expected_type=type_hints["deployments"])
            check_type(argname="argument discussions", value=discussions, expected_type=type_hints["discussions"])
            check_type(argname="argument id_token", value=id_token, expected_type=type_hints["id_token"])
            check_type(argname="argument issues", value=issues, expected_type=type_hints["issues"])
            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
            check_type(argname="argument pull_requests", value=pull_requests, expected_type=type_hints["pull_requests"])
            check_type(argname="argument repository_projects", value=repository_projects, expected_type=type_hints["repository_projects"])
            check_type(argname="argument security_events", value=security_events, expected_type=type_hints["security_events"])
            check_type(argname="argument statuses", value=statuses, expected_type=type_hints["statuses"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if actions is not None:
            self._values["actions"] = actions
        if checks is not None:
            self._values["checks"] = checks
        if contents is not None:
            self._values["contents"] = contents
        if deployments is not None:
            self._values["deployments"] = deployments
        if discussions is not None:
            self._values["discussions"] = discussions
        if id_token is not None:
            self._values["id_token"] = id_token
        if issues is not None:
            self._values["issues"] = issues
        if packages is not None:
            self._values["packages"] = packages
        if pull_requests is not None:
            self._values["pull_requests"] = pull_requests
        if repository_projects is not None:
            self._values["repository_projects"] = repository_projects
        if security_events is not None:
            self._values["security_events"] = security_events
        if statuses is not None:
            self._values["statuses"] = statuses

    @builtins.property
    def actions(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for GitHub Actions, affecting access to workflows.

        :stability: experimental
        '''
        result = self._values.get("actions")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def checks(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for check runs, enabling read or write access to check details.

        :stability: experimental
        '''
        result = self._values.get("checks")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def contents(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for repository contents, controlling file and directory access.

        :stability: experimental
        '''
        result = self._values.get("contents")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def deployments(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for deployments, affecting environment deployments in the repository.

        :stability: experimental
        '''
        result = self._values.get("deployments")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def discussions(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for discussions, enabling interaction with GitHub Discussions.

        :stability: experimental
        '''
        result = self._values.get("discussions")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def id_token(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for the GitHub OIDC (OpenID Connect) token, allowing secure identity verification.

        :stability: experimental
        '''
        result = self._values.get("id_token")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def issues(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for managing and interacting with issues in the repository.

        :stability: experimental
        '''
        result = self._values.get("issues")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def packages(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for packages in the GitHub Packages registry.

        :stability: experimental
        '''
        result = self._values.get("packages")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def pull_requests(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for interacting with pull requests in the repository.

        :stability: experimental
        '''
        result = self._values.get("pull_requests")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def repository_projects(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for repository projects, affecting project boards and related assets.

        :stability: experimental
        '''
        result = self._values.get("repository_projects")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def security_events(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for security events, such as vulnerability alerts.

        :stability: experimental
        '''
        result = self._values.get("security_events")
        return typing.cast(typing.Optional[PermissionLevel], result)

    @builtins.property
    def statuses(self) -> typing.Optional[PermissionLevel]:
        '''(experimental) Permissions for statuses, affecting commit statuses in the repository.

        :stability: experimental
        '''
        result = self._values.get("statuses")
        return typing.cast(typing.Optional[PermissionLevel], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PermissionsEvent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Project(
    _constructs_77d1e7e8.RootConstruct,
    metaclass=jsii.JSIIMeta,
    jsii_type="github-actions-cdk.Project",
):
    '''(experimental) Represents a GitHub Actions project, managing workflows and their output.

    ``Project`` provides an interface to synthesize and output GitHub Actions
    workflows as YAML files to a specified directory. Workflows added to the
    project are discovered and converted into YAML format upon synthesis.

    :stability: experimental
    '''

    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
        '''(experimental) Initializes a new ``Project`` instance.

        :param outdir: (experimental) Directory where the workflow YAML files will be generated. Specifies the target directory for outputting the YAML representation of the project workflows. Defaults to ``./.github/workflows`` if no directory is specified. Default: - "./.github/workflows"

        :stability: experimental
        '''
        props = ProjectProps(outdir=outdir)

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="addWorkflow")
    def add_workflow(
        self,
        id: builtins.str,
        *,
        concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        run_name: typing.Optional[builtins.str] = None,
        triggers: typing.Optional[typing.Union["WorkflowTriggers", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> "Workflow":
        '''(experimental) Adds a workflow to the project.

        This method allows for the creation of a new GitHub Actions workflow associated
        with the project, setting it up with a specific name and properties.

        :param id: - The id of the workflow, used as its identifier.
        :param concurrency: (experimental) Configuration for concurrency control of workflow runs.
        :param defaults: (experimental) Default configuration settings for jobs in this workflow.
        :param env: (experimental) Environment variables that will be available to all jobs in the workflow.
        :param name: (experimental) The name of the workflow. GitHub displays the names of your workflows under your repository's "Actions" tab. If you omit the name, GitHub displays the workflow file path relative to the root of the repository.
        :param permissions: (experimental) Permissions required by the workflow.
        :param run_name: (experimental) The name for workflow runs generated from the workflow. GitHub displays the workflow run name in the list of workflow runs on your repository's "Actions" tab. If ``run-name`` is omitted or is only whitespace, then the run name is set to event-specific information for the workflow run. For example, for a workflow triggered by a ``push`` or ``pull_request`` event, it is set as the commit message or the title of the pull request. This value can include expressions and can reference the ``github`` and ``inputs`` contexts.
        :param triggers: (experimental) Triggers that define when this workflow should run.

        :return: A new ``Workflow`` instance bound to this project.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f851528c9102c82f6c29bf01ec2c142ebc403fa63d25b0a6e4ede555270f048a)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = WorkflowProps(
            concurrency=concurrency,
            defaults=defaults,
            env=env,
            name=name,
            permissions=permissions,
            run_name=run_name,
            triggers=triggers,
        )

        return typing.cast("Workflow", jsii.invoke(self, "addWorkflow", [id, props]))

    @jsii.member(jsii_name="synth")
    def synth(self) -> None:
        '''(experimental) Synthesizes workflows into YAML files within the output directory.

        Finds all workflow constructs within the project, serializes them to
        YAML, and writes each one to the output directory with a ``.yml`` extension.
        Each workflow file is named based on the ``Workflow.name`` property.

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "synth", []))

    @builtins.property
    @jsii.member(jsii_name="outdir")
    def outdir(self) -> builtins.str:
        '''(experimental) The output directory where synthesized workflow models are saved.

        This directory is created if it does not exist, ensuring that all workflows
        are saved in the correct location during synthesis.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "outdir"))


@jsii.data_type(
    jsii_type="github-actions-cdk.ProjectCardOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class ProjectCardOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for project card events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad415eff52b84a055c84337c2805ce9044b826d99699d6689cc01763af6c8119)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProjectCardOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.ProjectColumnOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class ProjectColumnOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for project column events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c3004989fcc8d55376e3ef3a1db982fc0094ca209aa3573c22b231d6389d9e7)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProjectColumnOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.ProjectOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class ProjectOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for project events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67d88b3a3d6d856bdf249d58a343a9ef8740ccb7f40fe245ca15140bf5b34fdb)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProjectOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.ProjectProps",
    jsii_struct_bases=[],
    name_mapping={"outdir": "outdir"},
)
class ProjectProps:
    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
        '''(experimental) Properties for configuring a Project instance.

        :param outdir: (experimental) Directory where the workflow YAML files will be generated. Specifies the target directory for outputting the YAML representation of the project workflows. Defaults to ``./.github/workflows`` if no directory is specified. Default: - "./.github/workflows"

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__450639eccdc42a348c0099dbce603df8cd9197de52538522be8040114716859d)
            check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if outdir is not None:
            self._values["outdir"] = outdir

    @builtins.property
    def outdir(self) -> typing.Optional[builtins.str]:
        '''(experimental) Directory where the workflow YAML files will be generated.

        Specifies the target directory for outputting the YAML representation of the
        project workflows. Defaults to ``./.github/workflows`` if no directory is specified.

        :default: - "./.github/workflows"

        :stability: experimental
        '''
        result = self._values.get("outdir")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProjectProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.PullRequestOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class PullRequestOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for pull request events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68171705c985be084dbdca2a1ff2fd3444b5e640d632c443aa15eba47ab5bb67)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PullRequestOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.PullRequestReviewCommentOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class PullRequestReviewCommentOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for pull request review comment events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1607ee4b141291975fd72d3420b264f24669240b48469ea6fec28a7bb7c524e)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PullRequestReviewCommentOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.PullRequestReviewOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class PullRequestReviewOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for pull request review events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5c37c0870fb5ff9b5dceab001bb8fd29e70d138f195ff3a791bbf8f4da178c7)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PullRequestReviewOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.PushOptions",
    jsii_struct_bases=[],
    name_mapping={"branches": "branches", "paths": "paths", "tags": "tags"},
)
class PushOptions:
    def __init__(
        self,
        *,
        branches: typing.Optional[typing.Sequence[builtins.str]] = None,
        paths: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for push-like events, such as specifying branches, tags, and paths.

        :param branches: (experimental) Branches to trigger on. For pull requests, only base branches are evaluated.
        :param paths: (experimental) File path patterns to trigger on. Default: - triggers on all paths
        :param tags: (experimental) Tags to trigger on. Default: - triggers on all tags

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b2dbee06284bd070f84759371f9d3e47ea1a2959e2747c9ef5348e41c0507fd)
            check_type(argname="argument branches", value=branches, expected_type=type_hints["branches"])
            check_type(argname="argument paths", value=paths, expected_type=type_hints["paths"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if branches is not None:
            self._values["branches"] = branches
        if paths is not None:
            self._values["paths"] = paths
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def branches(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Branches to trigger on.

        For pull requests, only base branches are evaluated.

        :see: https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet
        :stability: experimental
        '''
        result = self._values.get("branches")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def paths(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) File path patterns to trigger on.

        :default: - triggers on all paths

        :stability: experimental
        '''
        result = self._values.get("paths")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Tags to trigger on.

        :default: - triggers on all tags

        :stability: experimental
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PushOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.RegistryPackageOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class RegistryPackageOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for registry package events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51ffb436656ac8c1233b106fe75017220f3ca1cbe93321807f6a71425e7024e4)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RegistryPackageOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.ReleaseOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class ReleaseOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for release events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__901c704f807a3bc66d62aca75564f6e9fa9ee5ef0df3967465126a7358291a92)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ReleaseOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.RepositoryDispatchOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class RepositoryDispatchOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for triggering on repository dispatch events.

        :param types: (experimental) List of activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a077abe81a20c3b60a3bd4ce5d7da8a5d920dbc1e7cbe5febe1d4f88fec3359d)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) List of activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RepositoryDispatchOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.RunSettings",
    jsii_struct_bases=[],
    name_mapping={"shell": "shell", "working_directory": "workingDirectory"},
)
class RunSettings:
    def __init__(
        self,
        *,
        shell: typing.Optional[builtins.str] = None,
        working_directory: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Configuration options for the execution environment of a job's steps.

        ``RunSettings`` provides control over the shell, working directory, and other
        environment-specific options used when running commands in a job step.

        :param shell: (experimental) Specifies the shell to use for executing the step's commands. This property allows you to define the command-line shell used for the step. Common options include ``bash``, ``sh``, ``cmd``, ``powershell``, or ``python``, depending on the operating system and specific requirements of the step. Default: The shell is determined automatically based on the operating system and job configuration.
        :param working_directory: (experimental) Defines the working directory for the step. The ``workingDirectory`` specifies the file path where the command should be executed. This can be an absolute path or relative to the root of the GitHub workspace. If not specified, the default working directory is the GitHub workspace root (typically ``/home/runner/work/{repo-name}/{repo-name}`` on Linux runners).

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__136f7dd5df10bc3efc63ac68784be915348e8e271405b406ee967bb475a85aa3)
            check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
            check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if shell is not None:
            self._values["shell"] = shell
        if working_directory is not None:
            self._values["working_directory"] = working_directory

    @builtins.property
    def shell(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the shell to use for executing the step's commands.

        This property allows you to define the command-line shell used for the step.
        Common options include ``bash``, ``sh``, ``cmd``, ``powershell``, or ``python``, depending
        on the operating system and specific requirements of the step.

        :default:

        The shell is determined automatically based on the operating system
        and job configuration.

        :stability: experimental

        Example::

            shell: "powershell"
        '''
        result = self._values.get("shell")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def working_directory(self) -> typing.Optional[builtins.str]:
        '''(experimental) Defines the working directory for the step.

        The ``workingDirectory`` specifies the file path where the command should be executed.
        This can be an absolute path or relative to the root of the GitHub workspace.
        If not specified, the default working directory is the GitHub workspace root
        (typically ``/home/runner/work/{repo-name}/{repo-name}`` on Linux runners).

        :stability: experimental

        Example::

            workingDirectory: "/home/runner/work/my-repo/my-repo"
        '''
        result = self._values.get("working_directory")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RunSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Step(Component, metaclass=jsii.JSIIMeta, jsii_type="github-actions-cdk.Step"):
    '''(experimental) Represents a single step within a GitHub Actions job.

    A ``Step`` can run commands or actions and supports conditional execution,
    environment variables, input parameters, and more.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.IConstruct,
        id: builtins.str,
        *,
        condition: typing.Optional[builtins.str] = None,
        continue_on_error: typing.Optional[builtins.bool] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        run: typing.Optional[typing.Sequence[builtins.str]] = None,
        shell: typing.Optional[builtins.str] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
        uses: typing.Optional[builtins.str] = None,
        working_directory: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Creates a new ``Step`` instance.

        :param scope: - The scope in which to define this construct.
        :param id: - The identifier for this step.
        :param condition: (experimental) Conditional expression to determine if the step should run. (corresponds to ``if`` in GitHub Actions). This can include GitHub Actions contexts and expressions, allowing conditions like ``${{ success() }}`` or ``${{ github.event_name == 'push' }}``.
        :param continue_on_error: (experimental) Controls whether the job should continue if this step fails. Set to ``true`` to allow the job to proceed even if this step encounters an error. Default: false
        :param env: (experimental) Environment variables available to this step. Step-specific environment variables are accessible within the shell or action, overriding any workflow or job-level environment settings.
        :param name: (experimental) A descriptive name for the step, displayed in the GitHub Actions UI.
        :param parameters: (experimental) Input parameters for the action specified in ``uses``. (corresponds to ``with`` in GitHub Actions). This is a key-value map of input parameters that the action can access as environment variables, each prefixed with ``INPUT_``.
        :param run: (experimental) A shell command or script to run in this step. Runs specified command-line programs or scripts in the step's shell. If ``name`` is not specified, this command's text will display as the step name.
        :param shell: (experimental) A shell specification to define the shell environment for this step. Allows specifying a shell other than the default, such as ``bash``, ``powershell``, etc. Default: "bash"
        :param timeout_minutes: (experimental) Maximum execution time for the step, in minutes. After this time, the step is terminated to prevent indefinite execution.
        :param uses: (experimental) Specifies an action to run in this step. Defines a reusable action from the same repository, a public repository, or a Docker container. Actions provide predefined functionality to avoid custom scripting for common tasks.
        :param working_directory: (experimental) Specifies the working directory for the step. Sets the directory in which the step's command or action runs. If not specified, it defaults to the job's working directory.

        :stability: experimental
        :throws: Error if both ``uses`` and ``run`` are specified.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25c98a57404d7e679d999225ee4bc5f4c68894402219ca95923b0ed08d4500eb)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = StepProps(
            condition=condition,
            continue_on_error=continue_on_error,
            env=env,
            name=name,
            parameters=parameters,
            run=run,
            shell=shell,
            timeout_minutes=timeout_minutes,
            uses=uses,
            working_directory=working_directory,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        '''(experimental) Gets the step's unique identifier.

        This identifier can be used to reference the step within the context of
        a workflow job.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="condition")
    def condition(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "condition"))

    @builtins.property
    @jsii.member(jsii_name="continueOnError")
    def continue_on_error(self) -> typing.Optional[builtins.bool]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "continueOnError"))

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "env"))

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], jsii.get(self, "parameters"))

    @builtins.property
    @jsii.member(jsii_name="run")
    def run(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "run"))

    @builtins.property
    @jsii.member(jsii_name="shell")
    def shell(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "shell"))

    @builtins.property
    @jsii.member(jsii_name="timeoutMinutes")
    def timeout_minutes(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "timeoutMinutes"))

    @builtins.property
    @jsii.member(jsii_name="uses")
    def uses(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "uses"))

    @builtins.property
    @jsii.member(jsii_name="workingDirectory")
    def working_directory(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "workingDirectory"))


@jsii.data_type(
    jsii_type="github-actions-cdk.StepProps",
    jsii_struct_bases=[],
    name_mapping={
        "condition": "condition",
        "continue_on_error": "continueOnError",
        "env": "env",
        "name": "name",
        "parameters": "parameters",
        "run": "run",
        "shell": "shell",
        "timeout_minutes": "timeoutMinutes",
        "uses": "uses",
        "working_directory": "workingDirectory",
    },
)
class StepProps:
    def __init__(
        self,
        *,
        condition: typing.Optional[builtins.str] = None,
        continue_on_error: typing.Optional[builtins.bool] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        run: typing.Optional[typing.Sequence[builtins.str]] = None,
        shell: typing.Optional[builtins.str] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
        uses: typing.Optional[builtins.str] = None,
        working_directory: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Properties for configuring an individual step in a GitHub Actions workflow job.

        :param condition: (experimental) Conditional expression to determine if the step should run. (corresponds to ``if`` in GitHub Actions). This can include GitHub Actions contexts and expressions, allowing conditions like ``${{ success() }}`` or ``${{ github.event_name == 'push' }}``.
        :param continue_on_error: (experimental) Controls whether the job should continue if this step fails. Set to ``true`` to allow the job to proceed even if this step encounters an error. Default: false
        :param env: (experimental) Environment variables available to this step. Step-specific environment variables are accessible within the shell or action, overriding any workflow or job-level environment settings.
        :param name: (experimental) A descriptive name for the step, displayed in the GitHub Actions UI.
        :param parameters: (experimental) Input parameters for the action specified in ``uses``. (corresponds to ``with`` in GitHub Actions). This is a key-value map of input parameters that the action can access as environment variables, each prefixed with ``INPUT_``.
        :param run: (experimental) A shell command or script to run in this step. Runs specified command-line programs or scripts in the step's shell. If ``name`` is not specified, this command's text will display as the step name.
        :param shell: (experimental) A shell specification to define the shell environment for this step. Allows specifying a shell other than the default, such as ``bash``, ``powershell``, etc. Default: "bash"
        :param timeout_minutes: (experimental) Maximum execution time for the step, in minutes. After this time, the step is terminated to prevent indefinite execution.
        :param uses: (experimental) Specifies an action to run in this step. Defines a reusable action from the same repository, a public repository, or a Docker container. Actions provide predefined functionality to avoid custom scripting for common tasks.
        :param working_directory: (experimental) Specifies the working directory for the step. Sets the directory in which the step's command or action runs. If not specified, it defaults to the job's working directory.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57024f82a005887d2af3b05c3642899af6fb14b2a703cce0f270b136bdb496ba)
            check_type(argname="argument condition", value=condition, expected_type=type_hints["condition"])
            check_type(argname="argument continue_on_error", value=continue_on_error, expected_type=type_hints["continue_on_error"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument run", value=run, expected_type=type_hints["run"])
            check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
            check_type(argname="argument timeout_minutes", value=timeout_minutes, expected_type=type_hints["timeout_minutes"])
            check_type(argname="argument uses", value=uses, expected_type=type_hints["uses"])
            check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if condition is not None:
            self._values["condition"] = condition
        if continue_on_error is not None:
            self._values["continue_on_error"] = continue_on_error
        if env is not None:
            self._values["env"] = env
        if name is not None:
            self._values["name"] = name
        if parameters is not None:
            self._values["parameters"] = parameters
        if run is not None:
            self._values["run"] = run
        if shell is not None:
            self._values["shell"] = shell
        if timeout_minutes is not None:
            self._values["timeout_minutes"] = timeout_minutes
        if uses is not None:
            self._values["uses"] = uses
        if working_directory is not None:
            self._values["working_directory"] = working_directory

    @builtins.property
    def condition(self) -> typing.Optional[builtins.str]:
        '''(experimental) Conditional expression to determine if the step should run. (corresponds to ``if`` in GitHub Actions).

        This can include GitHub Actions contexts and expressions, allowing
        conditions like ``${{ success() }}`` or ``${{ github.event_name == 'push' }}``.

        :stability: experimental
        '''
        result = self._values.get("condition")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def continue_on_error(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Controls whether the job should continue if this step fails.

        Set to ``true`` to allow the job to proceed even if this step encounters an error.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("continue_on_error")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''(experimental) Environment variables available to this step.

        Step-specific environment variables are accessible within the shell
        or action, overriding any workflow or job-level environment settings.

        :stability: experimental
        '''
        result = self._values.get("env")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''(experimental) A descriptive name for the step, displayed in the GitHub Actions UI.

        :stability: experimental

        Example::

            "Install dependencies"
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) Input parameters for the action specified in ``uses``. (corresponds to ``with`` in GitHub Actions).

        This is a key-value map of input parameters that the action can access
        as environment variables, each prefixed with ``INPUT_``.

        :stability: experimental
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def run(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) A shell command or script to run in this step.

        Runs specified command-line programs or scripts in the step's shell.
        If ``name`` is not specified, this command's text will display as the step name.

        :stability: experimental

        Example::

            "npm install"
        '''
        result = self._values.get("run")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def shell(self) -> typing.Optional[builtins.str]:
        '''(experimental) A shell specification to define the shell environment for this step.

        Allows specifying a shell other than the default, such as ``bash``, ``powershell``, etc.

        :default: "bash"

        :stability: experimental

        Example::

            "pwsh"
        '''
        result = self._values.get("shell")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeout_minutes(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Maximum execution time for the step, in minutes.

        After this time, the step is terminated to prevent indefinite execution.

        :stability: experimental
        '''
        result = self._values.get("timeout_minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def uses(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies an action to run in this step.

        Defines a reusable action from the same repository, a public repository,
        or a Docker container. Actions provide predefined functionality to avoid
        custom scripting for common tasks.

        :stability: experimental

        Example::

            "actions/checkout@v2"
        '''
        result = self._values.get("uses")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def working_directory(self) -> typing.Optional[builtins.str]:
        '''(experimental) Specifies the working directory for the step.

        Sets the directory in which the step's command or action runs. If not specified,
        it defaults to the job's working directory.

        :stability: experimental

        Example::

            "src/"
        '''
        result = self._values.get("working_directory")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.Strategy",
    jsii_struct_bases=[],
    name_mapping={
        "fail_fast": "failFast",
        "matrix": "matrix",
        "max_parallel": "maxParallel",
    },
)
class Strategy:
    def __init__(
        self,
        *,
        fail_fast: typing.Optional[builtins.bool] = None,
        matrix: typing.Optional[typing.Union[Matrix, typing.Dict[builtins.str, typing.Any]]] = None,
        max_parallel: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fail_fast: (experimental) When set to true, GitHub cancels all in-progress jobs if any matrix job fails. Default: true
        :param matrix: (experimental) You can define a matrix of different job configurations. A matrix allows you to create multiple jobs by performing variable substitution in a single job definition. For example, you can use a matrix to create jobs for more than one supported version of a programming language, operating system, or tool. A matrix reuses the job's configuration and creates a job for each matrix you configure. A job matrix can generate a maximum of 256 jobs per workflow run. This limit also applies to self-hosted runners.
        :param max_parallel: (experimental) The maximum number of jobs that can run simultaneously when using a matrix job strategy. By default, GitHub will maximize the number of jobs run in parallel depending on the available runners on GitHub-hosted virtual machines.

        :stability: experimental
        '''
        if isinstance(matrix, dict):
            matrix = Matrix(**matrix)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__940058bd717a823643f0fa71e7845f3424e4d1bb4f6b6e9d54c9d10888d7c231)
            check_type(argname="argument fail_fast", value=fail_fast, expected_type=type_hints["fail_fast"])
            check_type(argname="argument matrix", value=matrix, expected_type=type_hints["matrix"])
            check_type(argname="argument max_parallel", value=max_parallel, expected_type=type_hints["max_parallel"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if fail_fast is not None:
            self._values["fail_fast"] = fail_fast
        if matrix is not None:
            self._values["matrix"] = matrix
        if max_parallel is not None:
            self._values["max_parallel"] = max_parallel

    @builtins.property
    def fail_fast(self) -> typing.Optional[builtins.bool]:
        '''(experimental) When set to true, GitHub cancels all in-progress jobs if any matrix job fails.

        Default: true

        :stability: experimental
        '''
        result = self._values.get("fail_fast")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def matrix(self) -> typing.Optional[Matrix]:
        '''(experimental) You can define a matrix of different job configurations.

        A matrix allows
        you to create multiple jobs by performing variable substitution in a
        single job definition. For example, you can use a matrix to create jobs
        for more than one supported version of a programming language, operating
        system, or tool. A matrix reuses the job's configuration and creates a
        job for each matrix you configure.

        A job matrix can generate a maximum of 256 jobs per workflow run. This
        limit also applies to self-hosted runners.

        :stability: experimental
        '''
        result = self._values.get("matrix")
        return typing.cast(typing.Optional[Matrix], result)

    @builtins.property
    def max_parallel(self) -> typing.Optional[jsii.Number]:
        '''(experimental) The maximum number of jobs that can run simultaneously when using a matrix job strategy.

        By default, GitHub will maximize the number of jobs
        run in parallel depending on the available runners on GitHub-hosted
        virtual machines.

        :stability: experimental
        '''
        result = self._values.get("max_parallel")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Strategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.WatchOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class WatchOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for watch events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__785dc16d175b076483963c67da231a63908f82840f73cbe4b3bec91891692591)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WatchOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Workflow(
    Component,
    metaclass=jsii.JSIIMeta,
    jsii_type="github-actions-cdk.Workflow",
):
    '''(experimental) Represents a GitHub Workflow.

    This class defines the workflow, its triggers, environment variables,
    defaults, permissions, concurrency settings, and allows for job creation.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.IConstruct,
        id: builtins.str,
        *,
        concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        run_name: typing.Optional[builtins.str] = None,
        triggers: typing.Optional[typing.Union["WorkflowTriggers", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''(experimental) Initializes a new instance of the Workflow class.

        :param scope: - The construct scope.
        :param id: - The id of the workflow.
        :param concurrency: (experimental) Configuration for concurrency control of workflow runs.
        :param defaults: (experimental) Default configuration settings for jobs in this workflow.
        :param env: (experimental) Environment variables that will be available to all jobs in the workflow.
        :param name: (experimental) The name of the workflow. GitHub displays the names of your workflows under your repository's "Actions" tab. If you omit the name, GitHub displays the workflow file path relative to the root of the repository.
        :param permissions: (experimental) Permissions required by the workflow.
        :param run_name: (experimental) The name for workflow runs generated from the workflow. GitHub displays the workflow run name in the list of workflow runs on your repository's "Actions" tab. If ``run-name`` is omitted or is only whitespace, then the run name is set to event-specific information for the workflow run. For example, for a workflow triggered by a ``push`` or ``pull_request`` event, it is set as the commit message or the title of the pull request. This value can include expressions and can reference the ``github`` and ``inputs`` contexts.
        :param triggers: (experimental) Triggers that define when this workflow should run.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdbc398a16d0309222333c5d160ce820ecd2201180eefcc6e06ee4dbca746de0)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = WorkflowProps(
            concurrency=concurrency,
            defaults=defaults,
            env=env,
            name=name,
            permissions=permissions,
            run_name=run_name,
            triggers=triggers,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addJob")
    def add_job(
        self,
        id: builtins.str,
        *,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        environment: typing.Any = None,
        name: typing.Optional[builtins.str] = None,
        needs: typing.Optional[typing.Sequence[builtins.str]] = None,
        outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
        runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
        strategy: typing.Optional[typing.Union[Strategy, typing.Dict[builtins.str, typing.Any]]] = None,
        timeout_minutes: typing.Optional[jsii.Number] = None,
    ) -> Job:
        '''(experimental) Adds a new job to the workflow.

        :param id: - The id of the job.
        :param defaults: (experimental) Default settings to apply to all steps in the job. These settings provide default values for ``shell``, ``workingDirectory``, and other options for each step in the job, allowing for consistent configuration across steps. Job-level defaults can override workflow-level defaults, but can be overridden by individual step settings.
        :param env: (experimental) Environment variables available to all steps in the job. A key-value map of environment variables that are accessible by all steps within this job. Individual steps or the entire workflow can also set environment variables to further customize the environment.
        :param environment: (experimental) The environment this job targets. Specifies the GitHub environment referenced by this job. The job will be subject to any environment protection rules configured in the repository, such as approvals or restrictions.
        :param name: (experimental) The display name of the job in GitHub Actions. This name will appear in the Actions interface to represent this job.
        :param needs: (experimental) Specifies any jobs that must complete before this job runs. This property establishes dependencies between jobs, ensuring that specified jobs complete successfully before this job is initiated. It can be a string or an array of job IDs.
        :param outputs: (experimental) Defines outputs for the job that can be accessed by downstream jobs. A map of outputs produced by this job, which are accessible to other jobs that depend on it via the ``needs`` keyword.
        :param permissions: (experimental) Defines the permissions for this job. Use this to control the access levels and permissions available to the job, restricting or granting permissions for specific GitHub actions and resources.
        :param required_checks: (experimental) A set of required checks that must pass before the job can run. Useful for ensuring that certain status checks are completed before executing this job, improving the reliability of the workflow.
        :param runner_labels: (experimental) Specifies the job's runner labels. This allows you to filter runners by labels, which is particularly useful for self-hosted runners. You can provide a single label or an array of labels.
        :param runs_on: (experimental) The type of runner on which to execute the job. Defines the runner environment for the job, which can be either a GitHub-hosted or self-hosted runner. GitHub-hosted runners include options such as ``"ubuntu-latest"``, ``"windows-latest"``, and ``"macos-latest"``.
        :param strategy: (experimental) The strategy for running this job. Allows you to specify a matrix strategy to run the job multiple times with different configurations, like different Node.js versions or OS types.
        :param timeout_minutes: (experimental) The timeout in minutes for the job to complete. This defines how long GitHub Actions should wait for the job to finish before it is automatically canceled. This helps in managing long-running jobs. Default: 60

        :return: The created Job instance.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f34a806b49cc8fdf5c1996cee37edcf0e6e6b71f2f941a306977ec746287a7a3)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = JobProps(
            defaults=defaults,
            env=env,
            environment=environment,
            name=name,
            needs=needs,
            outputs=outputs,
            permissions=permissions,
            required_checks=required_checks,
            runner_labels=runner_labels,
            runs_on=runs_on,
            strategy=strategy,
            timeout_minutes=timeout_minutes,
        )

        return typing.cast(Job, jsii.invoke(self, "addJob", [id, props]))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        '''(experimental) Gets the id of the workflow.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="triggers")
    def triggers(self) -> "WorkflowTriggers":
        '''
        :stability: experimental
        '''
        return typing.cast("WorkflowTriggers", jsii.get(self, "triggers"))

    @builtins.property
    @jsii.member(jsii_name="concurrency")
    def concurrency(self) -> typing.Optional[ConcurrencyOptions]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[ConcurrencyOptions], jsii.get(self, "concurrency"))

    @builtins.property
    @jsii.member(jsii_name="defaults")
    def defaults(self) -> typing.Optional[Defaults]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[Defaults], jsii.get(self, "defaults"))

    @builtins.property
    @jsii.member(jsii_name="env")
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "env"))

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[PermissionsEvent, builtins.str]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[PermissionsEvent, builtins.str]], jsii.get(self, "permissions"))

    @builtins.property
    @jsii.member(jsii_name="runName")
    def run_name(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "runName"))


@jsii.data_type(
    jsii_type="github-actions-cdk.WorkflowProps",
    jsii_struct_bases=[],
    name_mapping={
        "concurrency": "concurrency",
        "defaults": "defaults",
        "env": "env",
        "name": "name",
        "permissions": "permissions",
        "run_name": "runName",
        "triggers": "triggers",
    },
)
class WorkflowProps:
    def __init__(
        self,
        *,
        concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
        run_name: typing.Optional[builtins.str] = None,
        triggers: typing.Optional[typing.Union["WorkflowTriggers", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''(experimental) Workflow configuration properties.

        :param concurrency: (experimental) Configuration for concurrency control of workflow runs.
        :param defaults: (experimental) Default configuration settings for jobs in this workflow.
        :param env: (experimental) Environment variables that will be available to all jobs in the workflow.
        :param name: (experimental) The name of the workflow. GitHub displays the names of your workflows under your repository's "Actions" tab. If you omit the name, GitHub displays the workflow file path relative to the root of the repository.
        :param permissions: (experimental) Permissions required by the workflow.
        :param run_name: (experimental) The name for workflow runs generated from the workflow. GitHub displays the workflow run name in the list of workflow runs on your repository's "Actions" tab. If ``run-name`` is omitted or is only whitespace, then the run name is set to event-specific information for the workflow run. For example, for a workflow triggered by a ``push`` or ``pull_request`` event, it is set as the commit message or the title of the pull request. This value can include expressions and can reference the ``github`` and ``inputs`` contexts.
        :param triggers: (experimental) Triggers that define when this workflow should run.

        :stability: experimental
        '''
        if isinstance(concurrency, dict):
            concurrency = ConcurrencyOptions(**concurrency)
        if isinstance(defaults, dict):
            defaults = Defaults(**defaults)
        if isinstance(triggers, dict):
            triggers = WorkflowTriggers(**triggers)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8c923454de3cef4072be6958820f7ace0189f13e0a83a631fe60e1bb68b6ba0)
            check_type(argname="argument concurrency", value=concurrency, expected_type=type_hints["concurrency"])
            check_type(argname="argument defaults", value=defaults, expected_type=type_hints["defaults"])
            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument run_name", value=run_name, expected_type=type_hints["run_name"])
            check_type(argname="argument triggers", value=triggers, expected_type=type_hints["triggers"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if concurrency is not None:
            self._values["concurrency"] = concurrency
        if defaults is not None:
            self._values["defaults"] = defaults
        if env is not None:
            self._values["env"] = env
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if run_name is not None:
            self._values["run_name"] = run_name
        if triggers is not None:
            self._values["triggers"] = triggers

    @builtins.property
    def concurrency(self) -> typing.Optional[ConcurrencyOptions]:
        '''(experimental) Configuration for concurrency control of workflow runs.

        :stability: experimental
        '''
        result = self._values.get("concurrency")
        return typing.cast(typing.Optional[ConcurrencyOptions], result)

    @builtins.property
    def defaults(self) -> typing.Optional[Defaults]:
        '''(experimental) Default configuration settings for jobs in this workflow.

        :stability: experimental
        '''
        result = self._values.get("defaults")
        return typing.cast(typing.Optional[Defaults], result)

    @builtins.property
    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''(experimental) Environment variables that will be available to all jobs in the workflow.

        :stability: experimental
        '''
        result = self._values.get("env")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''(experimental) The name of the workflow.

        GitHub displays the names of your workflows under your repository's "Actions" tab.
        If you omit the name, GitHub displays the workflow file path relative to the root of the repository.

        :stability: experimental

        Example::

            "CI/CD Pipeline"
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[PermissionsEvent, builtins.str]]:
        '''(experimental) Permissions required by the workflow.

        :stability: experimental
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[PermissionsEvent, builtins.str]], result)

    @builtins.property
    def run_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) The name for workflow runs generated from the workflow.

        GitHub displays the workflow run name in the list of workflow runs on your repository's "Actions" tab.
        If ``run-name`` is omitted or is only whitespace, then the run name is set to event-specific
        information for the workflow run. For example, for a workflow triggered by a ``push`` or
        ``pull_request`` event, it is set as the commit message or the title of the pull request.

        This value can include expressions and can reference the ``github`` and ``inputs`` contexts.

        :stability: experimental

        Example::

            run-name: Deploy to ${{ inputs.deploy_target }} by@$[object Object]
        '''
        result = self._values.get("run_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def triggers(self) -> typing.Optional["WorkflowTriggers"]:
        '''(experimental) Triggers that define when this workflow should run.

        :stability: experimental
        '''
        result = self._values.get("triggers")
        return typing.cast(typing.Optional["WorkflowTriggers"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkflowProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.WorkflowRunOptions",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class WorkflowRunOptions:
    def __init__(
        self,
        *,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for workflow run events.

        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35c782811768802411aa6ff7edcbe38992320a84757598048527ae3ac7bf30c0)
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkflowRunOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.WorkflowTriggers",
    jsii_struct_bases=[],
    name_mapping={
        "check_run": "checkRun",
        "check_suite": "checkSuite",
        "issue_comment": "issueComment",
        "issues": "issues",
        "label": "label",
        "milestone": "milestone",
        "project": "project",
        "project_card": "projectCard",
        "project_column": "projectColumn",
        "pull_request": "pullRequest",
        "pull_request_review": "pullRequestReview",
        "pull_request_review_comment": "pullRequestReviewComment",
        "pull_request_target": "pullRequestTarget",
        "push": "push",
        "registry_package": "registryPackage",
        "release": "release",
        "repository_dispatch": "repositoryDispatch",
        "schedule": "schedule",
        "watch": "watch",
        "workflow_dispatch": "workflowDispatch",
        "workflow_run": "workflowRun",
    },
)
class WorkflowTriggers:
    def __init__(
        self,
        *,
        check_run: typing.Optional[typing.Union[CheckRunOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        check_suite: typing.Optional[typing.Union[CheckSuiteOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        issue_comment: typing.Optional[typing.Union[IssueCommentOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        issues: typing.Optional[typing.Union[IssuesOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        label: typing.Optional[typing.Union[LabelOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        milestone: typing.Optional[typing.Union[MilestoneOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        project: typing.Optional[typing.Union[ProjectOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        project_card: typing.Optional[typing.Union[ProjectCardOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        project_column: typing.Optional[typing.Union[ProjectColumnOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        pull_request: typing.Optional[typing.Union[PullRequestOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        pull_request_review: typing.Optional[typing.Union[PullRequestReviewOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        pull_request_review_comment: typing.Optional[typing.Union[PullRequestReviewCommentOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        pull_request_target: typing.Optional[typing.Union["PullRequestTargetOptions", typing.Dict[builtins.str, typing.Any]]] = None,
        push: typing.Optional[typing.Union[PushOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        registry_package: typing.Optional[typing.Union[RegistryPackageOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        release: typing.Optional[typing.Union[ReleaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        repository_dispatch: typing.Optional[typing.Union[RepositoryDispatchOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        schedule: typing.Optional[typing.Sequence[typing.Union[CronScheduleOptions, typing.Dict[builtins.str, typing.Any]]]] = None,
        watch: typing.Optional[typing.Union[WatchOptions, typing.Dict[builtins.str, typing.Any]]] = None,
        workflow_dispatch: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        workflow_run: typing.Optional[typing.Union[WorkflowRunOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''(experimental) Available triggers for GitHub Workflows.

        :param check_run: (experimental) Triggers workflow based on check run events.
        :param check_suite: (experimental) Triggers workflow based on check suite events.
        :param issue_comment: (experimental) Triggers workflow based on issue comment events.
        :param issues: (experimental) Triggers workflow based on issue events.
        :param label: (experimental) Triggers workflow based on label events.
        :param milestone: (experimental) Triggers workflow based on milestone events.
        :param project: (experimental) Triggers workflow based on project events.
        :param project_card: (experimental) Triggers workflow based on project card events.
        :param project_column: (experimental) Triggers workflow based on project column events.
        :param pull_request: (experimental) Triggers workflow based on pull request events.
        :param pull_request_review: (experimental) Triggers workflow based on pull request review events.
        :param pull_request_review_comment: (experimental) Triggers workflow based on pull request review comment events.
        :param pull_request_target: (experimental) Triggers workflow based on pull request target events.
        :param push: (experimental) Triggers workflow based on push events to repository branches.
        :param registry_package: (experimental) Triggers workflow based on registry package publish/updates.
        :param release: (experimental) Triggers workflow based on release events.
        :param repository_dispatch: (experimental) Triggers workflow based on repository dispatch events from external activities.
        :param schedule: (experimental) Schedule for running workflows at specific UTC times using POSIX cron syntax.
        :param watch: (experimental) Triggers workflow based on watch events for repositories.
        :param workflow_dispatch: (experimental) Allows for manual triggering of workflows with custom input values.
        :param workflow_run: (experimental) Triggers workflow based on workflow run events.

        :stability: experimental
        '''
        if isinstance(check_run, dict):
            check_run = CheckRunOptions(**check_run)
        if isinstance(check_suite, dict):
            check_suite = CheckSuiteOptions(**check_suite)
        if isinstance(issue_comment, dict):
            issue_comment = IssueCommentOptions(**issue_comment)
        if isinstance(issues, dict):
            issues = IssuesOptions(**issues)
        if isinstance(label, dict):
            label = LabelOptions(**label)
        if isinstance(milestone, dict):
            milestone = MilestoneOptions(**milestone)
        if isinstance(project, dict):
            project = ProjectOptions(**project)
        if isinstance(project_card, dict):
            project_card = ProjectCardOptions(**project_card)
        if isinstance(project_column, dict):
            project_column = ProjectColumnOptions(**project_column)
        if isinstance(pull_request, dict):
            pull_request = PullRequestOptions(**pull_request)
        if isinstance(pull_request_review, dict):
            pull_request_review = PullRequestReviewOptions(**pull_request_review)
        if isinstance(pull_request_review_comment, dict):
            pull_request_review_comment = PullRequestReviewCommentOptions(**pull_request_review_comment)
        if isinstance(pull_request_target, dict):
            pull_request_target = PullRequestTargetOptions(**pull_request_target)
        if isinstance(push, dict):
            push = PushOptions(**push)
        if isinstance(registry_package, dict):
            registry_package = RegistryPackageOptions(**registry_package)
        if isinstance(release, dict):
            release = ReleaseOptions(**release)
        if isinstance(repository_dispatch, dict):
            repository_dispatch = RepositoryDispatchOptions(**repository_dispatch)
        if isinstance(watch, dict):
            watch = WatchOptions(**watch)
        if isinstance(workflow_run, dict):
            workflow_run = WorkflowRunOptions(**workflow_run)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc76e74c3cda759effeb55fe91653631fd5c1987a7e7836ecf7d77b5319583e2)
            check_type(argname="argument check_run", value=check_run, expected_type=type_hints["check_run"])
            check_type(argname="argument check_suite", value=check_suite, expected_type=type_hints["check_suite"])
            check_type(argname="argument issue_comment", value=issue_comment, expected_type=type_hints["issue_comment"])
            check_type(argname="argument issues", value=issues, expected_type=type_hints["issues"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument milestone", value=milestone, expected_type=type_hints["milestone"])
            check_type(argname="argument project", value=project, expected_type=type_hints["project"])
            check_type(argname="argument project_card", value=project_card, expected_type=type_hints["project_card"])
            check_type(argname="argument project_column", value=project_column, expected_type=type_hints["project_column"])
            check_type(argname="argument pull_request", value=pull_request, expected_type=type_hints["pull_request"])
            check_type(argname="argument pull_request_review", value=pull_request_review, expected_type=type_hints["pull_request_review"])
            check_type(argname="argument pull_request_review_comment", value=pull_request_review_comment, expected_type=type_hints["pull_request_review_comment"])
            check_type(argname="argument pull_request_target", value=pull_request_target, expected_type=type_hints["pull_request_target"])
            check_type(argname="argument push", value=push, expected_type=type_hints["push"])
            check_type(argname="argument registry_package", value=registry_package, expected_type=type_hints["registry_package"])
            check_type(argname="argument release", value=release, expected_type=type_hints["release"])
            check_type(argname="argument repository_dispatch", value=repository_dispatch, expected_type=type_hints["repository_dispatch"])
            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
            check_type(argname="argument watch", value=watch, expected_type=type_hints["watch"])
            check_type(argname="argument workflow_dispatch", value=workflow_dispatch, expected_type=type_hints["workflow_dispatch"])
            check_type(argname="argument workflow_run", value=workflow_run, expected_type=type_hints["workflow_run"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if check_run is not None:
            self._values["check_run"] = check_run
        if check_suite is not None:
            self._values["check_suite"] = check_suite
        if issue_comment is not None:
            self._values["issue_comment"] = issue_comment
        if issues is not None:
            self._values["issues"] = issues
        if label is not None:
            self._values["label"] = label
        if milestone is not None:
            self._values["milestone"] = milestone
        if project is not None:
            self._values["project"] = project
        if project_card is not None:
            self._values["project_card"] = project_card
        if project_column is not None:
            self._values["project_column"] = project_column
        if pull_request is not None:
            self._values["pull_request"] = pull_request
        if pull_request_review is not None:
            self._values["pull_request_review"] = pull_request_review
        if pull_request_review_comment is not None:
            self._values["pull_request_review_comment"] = pull_request_review_comment
        if pull_request_target is not None:
            self._values["pull_request_target"] = pull_request_target
        if push is not None:
            self._values["push"] = push
        if registry_package is not None:
            self._values["registry_package"] = registry_package
        if release is not None:
            self._values["release"] = release
        if repository_dispatch is not None:
            self._values["repository_dispatch"] = repository_dispatch
        if schedule is not None:
            self._values["schedule"] = schedule
        if watch is not None:
            self._values["watch"] = watch
        if workflow_dispatch is not None:
            self._values["workflow_dispatch"] = workflow_dispatch
        if workflow_run is not None:
            self._values["workflow_run"] = workflow_run

    @builtins.property
    def check_run(self) -> typing.Optional[CheckRunOptions]:
        '''(experimental) Triggers workflow based on check run events.

        :stability: experimental
        '''
        result = self._values.get("check_run")
        return typing.cast(typing.Optional[CheckRunOptions], result)

    @builtins.property
    def check_suite(self) -> typing.Optional[CheckSuiteOptions]:
        '''(experimental) Triggers workflow based on check suite events.

        :stability: experimental
        '''
        result = self._values.get("check_suite")
        return typing.cast(typing.Optional[CheckSuiteOptions], result)

    @builtins.property
    def issue_comment(self) -> typing.Optional[IssueCommentOptions]:
        '''(experimental) Triggers workflow based on issue comment events.

        :stability: experimental
        '''
        result = self._values.get("issue_comment")
        return typing.cast(typing.Optional[IssueCommentOptions], result)

    @builtins.property
    def issues(self) -> typing.Optional[IssuesOptions]:
        '''(experimental) Triggers workflow based on issue events.

        :stability: experimental
        '''
        result = self._values.get("issues")
        return typing.cast(typing.Optional[IssuesOptions], result)

    @builtins.property
    def label(self) -> typing.Optional[LabelOptions]:
        '''(experimental) Triggers workflow based on label events.

        :stability: experimental
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[LabelOptions], result)

    @builtins.property
    def milestone(self) -> typing.Optional[MilestoneOptions]:
        '''(experimental) Triggers workflow based on milestone events.

        :stability: experimental
        '''
        result = self._values.get("milestone")
        return typing.cast(typing.Optional[MilestoneOptions], result)

    @builtins.property
    def project(self) -> typing.Optional[ProjectOptions]:
        '''(experimental) Triggers workflow based on project events.

        :stability: experimental
        '''
        result = self._values.get("project")
        return typing.cast(typing.Optional[ProjectOptions], result)

    @builtins.property
    def project_card(self) -> typing.Optional[ProjectCardOptions]:
        '''(experimental) Triggers workflow based on project card events.

        :stability: experimental
        '''
        result = self._values.get("project_card")
        return typing.cast(typing.Optional[ProjectCardOptions], result)

    @builtins.property
    def project_column(self) -> typing.Optional[ProjectColumnOptions]:
        '''(experimental) Triggers workflow based on project column events.

        :stability: experimental
        '''
        result = self._values.get("project_column")
        return typing.cast(typing.Optional[ProjectColumnOptions], result)

    @builtins.property
    def pull_request(self) -> typing.Optional[PullRequestOptions]:
        '''(experimental) Triggers workflow based on pull request events.

        :stability: experimental
        '''
        result = self._values.get("pull_request")
        return typing.cast(typing.Optional[PullRequestOptions], result)

    @builtins.property
    def pull_request_review(self) -> typing.Optional[PullRequestReviewOptions]:
        '''(experimental) Triggers workflow based on pull request review events.

        :stability: experimental
        '''
        result = self._values.get("pull_request_review")
        return typing.cast(typing.Optional[PullRequestReviewOptions], result)

    @builtins.property
    def pull_request_review_comment(
        self,
    ) -> typing.Optional[PullRequestReviewCommentOptions]:
        '''(experimental) Triggers workflow based on pull request review comment events.

        :stability: experimental
        '''
        result = self._values.get("pull_request_review_comment")
        return typing.cast(typing.Optional[PullRequestReviewCommentOptions], result)

    @builtins.property
    def pull_request_target(self) -> typing.Optional["PullRequestTargetOptions"]:
        '''(experimental) Triggers workflow based on pull request target events.

        :stability: experimental
        '''
        result = self._values.get("pull_request_target")
        return typing.cast(typing.Optional["PullRequestTargetOptions"], result)

    @builtins.property
    def push(self) -> typing.Optional[PushOptions]:
        '''(experimental) Triggers workflow based on push events to repository branches.

        :stability: experimental
        '''
        result = self._values.get("push")
        return typing.cast(typing.Optional[PushOptions], result)

    @builtins.property
    def registry_package(self) -> typing.Optional[RegistryPackageOptions]:
        '''(experimental) Triggers workflow based on registry package publish/updates.

        :stability: experimental
        '''
        result = self._values.get("registry_package")
        return typing.cast(typing.Optional[RegistryPackageOptions], result)

    @builtins.property
    def release(self) -> typing.Optional[ReleaseOptions]:
        '''(experimental) Triggers workflow based on release events.

        :stability: experimental
        '''
        result = self._values.get("release")
        return typing.cast(typing.Optional[ReleaseOptions], result)

    @builtins.property
    def repository_dispatch(self) -> typing.Optional[RepositoryDispatchOptions]:
        '''(experimental) Triggers workflow based on repository dispatch events from external activities.

        :stability: experimental
        '''
        result = self._values.get("repository_dispatch")
        return typing.cast(typing.Optional[RepositoryDispatchOptions], result)

    @builtins.property
    def schedule(self) -> typing.Optional[typing.List[CronScheduleOptions]]:
        '''(experimental) Schedule for running workflows at specific UTC times using POSIX cron syntax.

        :stability: experimental
        '''
        result = self._values.get("schedule")
        return typing.cast(typing.Optional[typing.List[CronScheduleOptions]], result)

    @builtins.property
    def watch(self) -> typing.Optional[WatchOptions]:
        '''(experimental) Triggers workflow based on watch events for repositories.

        :stability: experimental
        '''
        result = self._values.get("watch")
        return typing.cast(typing.Optional[WatchOptions], result)

    @builtins.property
    def workflow_dispatch(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) Allows for manual triggering of workflows with custom input values.

        :stability: experimental
        '''
        result = self._values.get("workflow_dispatch")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def workflow_run(self) -> typing.Optional[WorkflowRunOptions]:
        '''(experimental) Triggers workflow based on workflow run events.

        :stability: experimental
        '''
        result = self._values.get("workflow_run")
        return typing.cast(typing.Optional[WorkflowRunOptions], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkflowTriggers(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="github-actions-cdk.PullRequestTargetOptions",
    jsii_struct_bases=[PushOptions],
    name_mapping={
        "branches": "branches",
        "paths": "paths",
        "tags": "tags",
        "types": "types",
    },
)
class PullRequestTargetOptions(PushOptions):
    def __init__(
        self,
        *,
        branches: typing.Optional[typing.Sequence[builtins.str]] = None,
        paths: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''(experimental) Options for pull request target events.

        Extends push options.

        :param branches: (experimental) Branches to trigger on. For pull requests, only base branches are evaluated.
        :param paths: (experimental) File path patterns to trigger on. Default: - triggers on all paths
        :param tags: (experimental) Tags to trigger on. Default: - triggers on all tags
        :param types: (experimental) Activity types to trigger on. Default: - triggers on all activity types

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1319d4d58bfbf23a563a7e1f5938f52dd59aa97e218664fd9084b683391cb7df)
            check_type(argname="argument branches", value=branches, expected_type=type_hints["branches"])
            check_type(argname="argument paths", value=paths, expected_type=type_hints["paths"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument types", value=types, expected_type=type_hints["types"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if branches is not None:
            self._values["branches"] = branches
        if paths is not None:
            self._values["paths"] = paths
        if tags is not None:
            self._values["tags"] = tags
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def branches(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Branches to trigger on.

        For pull requests, only base branches are evaluated.

        :see: https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions#filter-pattern-cheat-sheet
        :stability: experimental
        '''
        result = self._values.get("branches")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def paths(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) File path patterns to trigger on.

        :default: - triggers on all paths

        :stability: experimental
        '''
        result = self._values.get("paths")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Tags to trigger on.

        :default: - triggers on all tags

        :stability: experimental
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) Activity types to trigger on.

        :default: - triggers on all activity types

        :stability: experimental
        '''
        result = self._values.get("types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PullRequestTargetOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "Action",
    "ActionProps",
    "CheckRunOptions",
    "CheckSuiteOptions",
    "Component",
    "ConcurrencyOptions",
    "Cron",
    "CronOptions",
    "CronScheduleOptions",
    "Defaults",
    "IssueCommentOptions",
    "IssuesOptions",
    "Job",
    "JobProps",
    "LabelOptions",
    "Matrix",
    "MilestoneOptions",
    "PermissionLevel",
    "PermissionsEvent",
    "Project",
    "ProjectCardOptions",
    "ProjectColumnOptions",
    "ProjectOptions",
    "ProjectProps",
    "PullRequestOptions",
    "PullRequestReviewCommentOptions",
    "PullRequestReviewOptions",
    "PullRequestTargetOptions",
    "PushOptions",
    "RegistryPackageOptions",
    "ReleaseOptions",
    "RepositoryDispatchOptions",
    "RunSettings",
    "Step",
    "StepProps",
    "Strategy",
    "WatchOptions",
    "Workflow",
    "WorkflowProps",
    "WorkflowRunOptions",
    "WorkflowTriggers",
]

publication.publish()

def _typecheckingstub__e9083af845695d517fd188c807376a21723381078b0375f588720ba0e18af144(
    id: builtins.str,
    *,
    version: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__248c74fec40098022456d69af388ef2f6b3ae1d3aebe3b790420bcff20621841(
    job: Job,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c67d92ddddb47d887e29da7bf6b0e42ad1021d78b44eb09fe02d19b70124b79(
    *,
    version: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5072f3495f4b3ba39176b029f0940e9c79221c2d0e31e596908947c243e493d1(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e104de4e65a228ba7996b869572411dc7ad5e1a2a7d6121de1f6ccd55f0e0e0(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cead5b79c90c5d033e0e67c6a4b6ab32d75b9b25a356a33e670e380460cbd641(
    scope: _constructs_77d1e7e8.IConstruct,
    id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fdef1626108471936d90bdb773b97c0ad75e293b12de823502fcf8c725662c2(
    x: typing.Any,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b13408e5c019460595cf165919cb1c57a2410148d6fb00d9d9defcb7d65e776(
    *,
    group: builtins.str,
    cancel_in_progress: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__421e7476c56b104ee34b40b641f796adb4f6ed1124a2b669faba030276256f6c(
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f87d77789ba0ef97f504cc1ff5b1ad08e4c6aaf974d775c90a3fa4d819bc2d9(
    *,
    day: typing.Optional[builtins.str] = None,
    hour: typing.Optional[builtins.str] = None,
    minute: typing.Optional[builtins.str] = None,
    month: typing.Optional[builtins.str] = None,
    week_day: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__199600a8fe0c62df3cbff7bfcacbbf2f8e629df37768f92e7958220548d6dd60(
    *,
    cron: Cron,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37fef6d91b1101241267e5d35cbcd7e3ed2eb1139f4522bfcd355fc98907624f(
    *,
    run: typing.Optional[typing.Union[RunSettings, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9245f610dfdf28f8846ab53cd23fb911806e86522c4cea0c3e62e5529532c5bc(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf87540107a62d8d64ed58e95f8b01db8159513fdd767fdd8c3f30aa87899b9e(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba74ac8c28c96ce71749c13835adfaf0239f2f521dd066f17e0e73c75ff7d315(
    scope: _constructs_77d1e7e8.IConstruct,
    id: builtins.str,
    *,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    environment: typing.Any = None,
    name: typing.Optional[builtins.str] = None,
    needs: typing.Optional[typing.Sequence[builtins.str]] = None,
    outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
    runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    strategy: typing.Optional[typing.Union[Strategy, typing.Dict[builtins.str, typing.Any]]] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14666f0e16559875db8b555895bfc36563ba36305480f7bd9e1f3cf88ceeca66(
    action: Action,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c84ddb7613f0dc156744978622a36eaccf42eb24f73fb68aadd45210e8a453a(
    name: builtins.str,
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77084fa240cf0938b5ba7ecabdd97e763b728b544776f87ea0b277d4ce0b8c4c(
    id: builtins.str,
    *,
    condition: typing.Optional[builtins.str] = None,
    continue_on_error: typing.Optional[builtins.bool] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    run: typing.Optional[typing.Sequence[builtins.str]] = None,
    shell: typing.Optional[builtins.str] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
    uses: typing.Optional[builtins.str] = None,
    working_directory: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20769971cc29ac6695fc59fa70f7ce92e7e4f43121f480d0ffcda1a97016201b(
    *,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    environment: typing.Any = None,
    name: typing.Optional[builtins.str] = None,
    needs: typing.Optional[typing.Sequence[builtins.str]] = None,
    outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
    runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    strategy: typing.Optional[typing.Union[Strategy, typing.Dict[builtins.str, typing.Any]]] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb9e02a1d086f2f6835ff0ea1688329d1c317ce50ab856b1f80f5638e1cece8f(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03098613492927ce72af982b6409517ead55bde8380b16f202b5570d740d05fc(
    *,
    domain: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
    exclude: typing.Optional[typing.Sequence[typing.Mapping[builtins.str, builtins.str]]] = None,
    include: typing.Optional[typing.Sequence[typing.Mapping[builtins.str, builtins.str]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de2c4c22ac0039acb049ce3c2e609e65738cb30ba50ee75b76ee87ddb332ad6f(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__250bfcabc87a33880947a3c29504b6eba32fdb6d7ba0d62131a0d5f9b95f3f5a(
    *,
    actions: typing.Optional[PermissionLevel] = None,
    checks: typing.Optional[PermissionLevel] = None,
    contents: typing.Optional[PermissionLevel] = None,
    deployments: typing.Optional[PermissionLevel] = None,
    discussions: typing.Optional[PermissionLevel] = None,
    id_token: typing.Optional[PermissionLevel] = None,
    issues: typing.Optional[PermissionLevel] = None,
    packages: typing.Optional[PermissionLevel] = None,
    pull_requests: typing.Optional[PermissionLevel] = None,
    repository_projects: typing.Optional[PermissionLevel] = None,
    security_events: typing.Optional[PermissionLevel] = None,
    statuses: typing.Optional[PermissionLevel] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f851528c9102c82f6c29bf01ec2c142ebc403fa63d25b0a6e4ede555270f048a(
    id: builtins.str,
    *,
    concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    run_name: typing.Optional[builtins.str] = None,
    triggers: typing.Optional[typing.Union[WorkflowTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad415eff52b84a055c84337c2805ce9044b826d99699d6689cc01763af6c8119(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c3004989fcc8d55376e3ef3a1db982fc0094ca209aa3573c22b231d6389d9e7(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67d88b3a3d6d856bdf249d58a343a9ef8740ccb7f40fe245ca15140bf5b34fdb(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__450639eccdc42a348c0099dbce603df8cd9197de52538522be8040114716859d(
    *,
    outdir: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68171705c985be084dbdca2a1ff2fd3444b5e640d632c443aa15eba47ab5bb67(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1607ee4b141291975fd72d3420b264f24669240b48469ea6fec28a7bb7c524e(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5c37c0870fb5ff9b5dceab001bb8fd29e70d138f195ff3a791bbf8f4da178c7(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b2dbee06284bd070f84759371f9d3e47ea1a2959e2747c9ef5348e41c0507fd(
    *,
    branches: typing.Optional[typing.Sequence[builtins.str]] = None,
    paths: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51ffb436656ac8c1233b106fe75017220f3ca1cbe93321807f6a71425e7024e4(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__901c704f807a3bc66d62aca75564f6e9fa9ee5ef0df3967465126a7358291a92(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a077abe81a20c3b60a3bd4ce5d7da8a5d920dbc1e7cbe5febe1d4f88fec3359d(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__136f7dd5df10bc3efc63ac68784be915348e8e271405b406ee967bb475a85aa3(
    *,
    shell: typing.Optional[builtins.str] = None,
    working_directory: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25c98a57404d7e679d999225ee4bc5f4c68894402219ca95923b0ed08d4500eb(
    scope: _constructs_77d1e7e8.IConstruct,
    id: builtins.str,
    *,
    condition: typing.Optional[builtins.str] = None,
    continue_on_error: typing.Optional[builtins.bool] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    run: typing.Optional[typing.Sequence[builtins.str]] = None,
    shell: typing.Optional[builtins.str] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
    uses: typing.Optional[builtins.str] = None,
    working_directory: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57024f82a005887d2af3b05c3642899af6fb14b2a703cce0f270b136bdb496ba(
    *,
    condition: typing.Optional[builtins.str] = None,
    continue_on_error: typing.Optional[builtins.bool] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    run: typing.Optional[typing.Sequence[builtins.str]] = None,
    shell: typing.Optional[builtins.str] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
    uses: typing.Optional[builtins.str] = None,
    working_directory: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__940058bd717a823643f0fa71e7845f3424e4d1bb4f6b6e9d54c9d10888d7c231(
    *,
    fail_fast: typing.Optional[builtins.bool] = None,
    matrix: typing.Optional[typing.Union[Matrix, typing.Dict[builtins.str, typing.Any]]] = None,
    max_parallel: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785dc16d175b076483963c67da231a63908f82840f73cbe4b3bec91891692591(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbc398a16d0309222333c5d160ce820ecd2201180eefcc6e06ee4dbca746de0(
    scope: _constructs_77d1e7e8.IConstruct,
    id: builtins.str,
    *,
    concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    run_name: typing.Optional[builtins.str] = None,
    triggers: typing.Optional[typing.Union[WorkflowTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f34a806b49cc8fdf5c1996cee37edcf0e6e6b71f2f941a306977ec746287a7a3(
    id: builtins.str,
    *,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    environment: typing.Any = None,
    name: typing.Optional[builtins.str] = None,
    needs: typing.Optional[typing.Sequence[builtins.str]] = None,
    outputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    required_checks: typing.Optional[typing.Sequence[builtins.str]] = None,
    runner_labels: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    runs_on: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
    strategy: typing.Optional[typing.Union[Strategy, typing.Dict[builtins.str, typing.Any]]] = None,
    timeout_minutes: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8c923454de3cef4072be6958820f7ace0189f13e0a83a631fe60e1bb68b6ba0(
    *,
    concurrency: typing.Optional[typing.Union[ConcurrencyOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    defaults: typing.Optional[typing.Union[Defaults, typing.Dict[builtins.str, typing.Any]]] = None,
    env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[typing.Union[PermissionsEvent, typing.Dict[builtins.str, typing.Any]], builtins.str]] = None,
    run_name: typing.Optional[builtins.str] = None,
    triggers: typing.Optional[typing.Union[WorkflowTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35c782811768802411aa6ff7edcbe38992320a84757598048527ae3ac7bf30c0(
    *,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc76e74c3cda759effeb55fe91653631fd5c1987a7e7836ecf7d77b5319583e2(
    *,
    check_run: typing.Optional[typing.Union[CheckRunOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    check_suite: typing.Optional[typing.Union[CheckSuiteOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    issue_comment: typing.Optional[typing.Union[IssueCommentOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    issues: typing.Optional[typing.Union[IssuesOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    label: typing.Optional[typing.Union[LabelOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    milestone: typing.Optional[typing.Union[MilestoneOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    project: typing.Optional[typing.Union[ProjectOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    project_card: typing.Optional[typing.Union[ProjectCardOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    project_column: typing.Optional[typing.Union[ProjectColumnOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    pull_request: typing.Optional[typing.Union[PullRequestOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    pull_request_review: typing.Optional[typing.Union[PullRequestReviewOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    pull_request_review_comment: typing.Optional[typing.Union[PullRequestReviewCommentOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    pull_request_target: typing.Optional[typing.Union[PullRequestTargetOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    push: typing.Optional[typing.Union[PushOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    registry_package: typing.Optional[typing.Union[RegistryPackageOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    release: typing.Optional[typing.Union[ReleaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    repository_dispatch: typing.Optional[typing.Union[RepositoryDispatchOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    schedule: typing.Optional[typing.Sequence[typing.Union[CronScheduleOptions, typing.Dict[builtins.str, typing.Any]]]] = None,
    watch: typing.Optional[typing.Union[WatchOptions, typing.Dict[builtins.str, typing.Any]]] = None,
    workflow_dispatch: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
    workflow_run: typing.Optional[typing.Union[WorkflowRunOptions, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1319d4d58bfbf23a563a7e1f5938f52dd59aa97e218664fd9084b683391cb7df(
    *,
    branches: typing.Optional[typing.Sequence[builtins.str]] = None,
    paths: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
    types: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass
