export interface CronOptions {
    /**
     * Specifies the minute(s) the cron job should run.
     * Use `*` for every minute or specify a specific minute (0-59).
     * Multiple values can be separated by commas, ranges with `-`, and intervals with `/`.
     *
     * @default "*" - Every minute
     */
    readonly minute?: string;
    /**
     * Specifies the hour(s) the cron job should run.
     * Use `*` for every hour or specify a specific hour (0-23).
     * Multiple values can be separated by commas, ranges with `-`, and intervals with `/`.
     *
     * @default "*" - Every hour
     */
    readonly hour?: string;
    /**
     * Specifies the day(s) of the month the cron job should run.
     * Use `*` for every day, or specify a day (1-31).
     * Supports `L` for the last day of the month and `W` for weekdays.
     * Multiple values can be separated by commas, ranges with `-`, and intervals with `/`.
     *
     * @default "*" - Every day of the month
     */
    readonly day?: string;
    /**
     * Specifies the month(s) the cron job should run.
     * Use `*` for every month or specify a month (1-12 or JAN-DEC).
     * Multiple values can be separated by commas, ranges with `-`, and intervals with `/`.
     *
     * @default "*" - Every month
     */
    readonly month?: string;
    /**
     * Specifies the day(s) of the week the cron job should run.
     * Use `*` for every day of the week, or specify a specific day (0-6 or SUN-SAT).
     * Supports `L` for the last instance and `#` for specifying nth occurrence of the day in the month.
     * Multiple values can be separated by commas, ranges with `-`, and intervals with `/`.
     *
     * @default "*" - Any day of the week
     */
    readonly weekDay?: string;
}
export declare class Cron {
    readonly minute: string;
    readonly hour: string;
    readonly day: string;
    readonly month: string;
    readonly weekDay: string;
    readonly expression: string;
    /**
     * Constructs a new Cron instance using the specified options.
     * Generates a cron expression string from the input fields and validates it.
     *
     * @param props - The schedule options for the cron job.
     * @throws Will throw an error if the generated cron expression is invalid.
     */
    constructor(props?: CronOptions);
    /**
     * Converts the Cron instance to a cron expression string.
     *
     * @returns The cron expression string in "minute hour day month weekDay" format.
     */
    toString(): string;
    /**
     * Converts the Cron instance to a JSON representation (string format).
     *
     * @returns The cron expression string.
     */
    toJSON(): string;
    /**
     * Creates a Cron instance from a single cron expression string.
     *
     * @param expression - The cron expression string.
     * @returns A new Cron instance based on the provided expression.
     * @throws Will throw an error if the expression is invalid.
     */
    static fromExpression(expression: string): Cron;
}
/**
 * Validates the format of a cron expression string by checking each field
 * (minute, hour, day, month, and weekday) for compliance with standard cron
 * syntax, including special characters like `*`, `,`, `-`, `/`, `L`, `W`, and `#`.
 *
 * @param expression - The cron expression string to validate.
 * @returns True if the expression is valid, otherwise false.
 */
export declare function isValidCronExpression(expression: string): boolean;
